@@ -36,13 +36,13 @@ import org.broad.igv.feature.Range;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.Strand;
 import org.broad.igv.feature.genome.GenomeManager;
-import org.broad.igv.google.OAuthUtils;
 import org.broad.igv.logging.LogManager;
 import org.broad.igv.logging.Logger;
 import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.renderer.DataRange;
 import org.broad.igv.sam.AlignmentTrack;
+import org.broad.igv.sam.SortOption;
 import org.broad.igv.session.Session;
 import org.broad.igv.session.SessionReader;
 import org.broad.igv.session.SessionWriter;
@@ -103,7 +103,7 @@ public class CommandExecutor {
         log.debug("Executing: " + commandLine);
         try {
             if (args.size() == 0) {
-                return "Empty command string";
+                return result;
             }
 
             String cmd = args.get(0).toLowerCase();
@@ -204,8 +204,10 @@ public class CommandExecutor {
                 FrameManager.incrementZoom(1);
             } else if (cmd.equals("zoomout")) {
                 FrameManager.incrementZoom(-1);
-            } else if ("oauth".equals(cmd)) {
-                OAuthUtils.getInstance().getProvider().setAccessToken(param1);
+            } else if ("oauth".equals(cmd) || cmd.equalsIgnoreCase("setaccesstoken")) {
+                HttpUtils.getInstance().setAccessToken(param1, param2);
+            } else if (cmd.equals("clearaccesstokens")) {
+                HttpUtils.getInstance().clearAccessTokens();
             } else if (cmd.equalsIgnoreCase("sortByAttribute")) {
                 result = sortByAttribute(args);
             } else if (cmd.equalsIgnoreCase("fitTracks")) {
@@ -620,25 +622,14 @@ public class CommandExecutor {
             return result;
         }
 
-        String genomePath = genomeID;
-        if (!ParsingUtils.fileExists(genomePath)) {
-            String workingDirectory = System.getProperty("user.dir", "");
-            genomePath = FileUtils.getAbsolutePath(genomeID, workingDirectory);
-        }
-        if (ParsingUtils.fileExists(genomePath)) {
-            try {
-                GenomeManager.getInstance().loadGenome(genomePath, null);
-            } catch (IOException e) {
-                result = "ERROR: Could not load genome: " + genomeID;
-                MessageUtils.showMessage(result);
-            }
-
-        } else {
-            result = "ERROR: Could not locate genome: " + genomeID;
+        String genomePath = resolveFileReference(genomeID);
+        try {
+            GenomeManager.getInstance().loadGenome(genomePath, null);
+        } catch (IOException e) {
+            result = "ERROR: Could not load genome: " + genomeID;
             MessageUtils.showMessage(result);
         }
 
-
         return result;
     }
 
@@ -681,7 +672,7 @@ public class CommandExecutor {
         Map<String, String> ignore = null;
         String sort = null;
         String sortTag = null;
-        return loadFiles(fileString, index, coverage, name, format, locus, merge, ignore, sort, sortTag);
+        return loadFiles(fileString, index, coverage, name, format, locus, merge, ignore, sort, sortTag, true);
 
     }
 
@@ -695,6 +686,7 @@ public class CommandExecutor {
      * @param params
      * @param sort
      * @param sortTag    Used iff sort == SortOption.TAG
+     * @param dup
      * @return
      * @throws IOException
      */
@@ -707,132 +699,148 @@ public class CommandExecutor {
                      final boolean merge,
                      Map<String, String> params,
                      String sort,
-                     String sortTag) {
+                     String sortTag,
+                     boolean dup) {
 
-        boolean isDataURL = ParsingUtils.isDataURL(fileString);
+        boolean currentBatchSetting = Globals.isBatch();
+        try {
+            // Temporarily switch to batch mode to force synchronization of load followed by possible sort
+            Globals.setBatch(true);
 
-        List<String> files = isDataURL ? Arrays.asList(fileString) : breakFileString(fileString);
-        List<String> indexFiles = isDataURL ? null : breakFileString(indexString);
-        List<String> coverageFiles = breakFileString(coverageString);
-        List<String> names = breakFileString(nameString);
-        List<String> formats = breakFileString(formatString);
-        if (names != null && names.size() != files.size()) {
-            return "Error: If file is a comma-separated list, names must also be a comma-separated list of the same length";
-        }
-        if (indexFiles != null && indexFiles.size() != files.size()) {
-            return "Error: If file is a comma-separated list, index must also be a comma-separated list of the same length";
-        }
-        if (isDataURL && formatString == null) {
-            return "Error: format must be specified for dataURLs";
-        }
-
-        // Fix formats -- backward compatibility
-        if (formats != null) {
-            for (int i = 0; i < formats.size(); i++) {
-                String formatOrExt = decodeFileString(formats.get(i));
-                String format = formatOrExt.startsWith(".") ? formatOrExt.substring(1) : formatOrExt;
-                formats.set(i, format);
+            boolean isDataURL = ParsingUtils.isDataURL(fileString);
 
+            List<String> files = isDataURL ? Arrays.asList(fileString) : breakFileString(fileString);
+            List<String> indexFiles = isDataURL ? null : breakFileString(indexString);
+            List<String> coverageFiles = breakFileString(coverageString);
+            List<String> names = breakFileString(nameString);
+            List<String> formats = breakFileString(formatString);
+            if (names != null && names.size() != files.size()) {
+                return "Error: If file is a comma-separated list, names must also be a comma-separated list of the same length";
             }
-        }
-
-        List<ResourceLocator> fileLocators = new ArrayList<>();
-
-        if (!SessionReader.isSessionFile(fileString) && merge == false) {
-            igv.newSession();
-        }
-
-
-        // Create set of loaded files
-//        Set<String> loadedFiles = new HashSet<>();
-//        for (ResourceLocator rl : igv.getDataResourceLocators()) {
-//            loadedFiles.add(rl.getPath());
-//        }
-
-        // Loop through files
-
-        for (int fi = 0; fi < files.size(); fi++) {
-            String f = files.get(fi);
-            if (!FileUtils.isRemote(f)) {
-                File maybeFile = getFile(f);
-                if (maybeFile.exists()) {
-                    f = maybeFile.getAbsolutePath();
-                } else {
-                    maybeFile = new File(this.scriptDir, StringUtils.stripQuotes(f));
-                    if (maybeFile.exists()) {
-                        f = maybeFile.getAbsolutePath();
-                    }
-                }
+            if (indexFiles != null && indexFiles.size() != files.size()) {
+                return "Error: If file is a comma-separated list, index must also be a comma-separated list of the same length";
             }
-
-            if (isDataURL && formats == null) {
+            if (isDataURL && formatString == null) {
                 return "Error: format must be specified for dataURLs";
             }
 
-            // Skip already loaded files TODO -- make this optional?  Check for change?
-            //if (loadedFiles.contains(f)) continue;
+            // Fix formats -- backward compatibility
+            if (formats != null) {
+                for (int i = 0; i < formats.size(); i++) {
+                    String formatOrExt = decodeFileString(formats.get(i));
+                    String format = formatOrExt.startsWith(".") ? formatOrExt.substring(1) : formatOrExt;
+                    formats.set(i, format);
 
-            if (SessionReader.isSessionFile(f)) {
-                igv.loadSession(f, locus);
-            } else {
+                }
+            }
 
-                ResourceLocator rl = new ResourceLocator(f);
+            List<ResourceLocator> fileLocators = new ArrayList<>();
 
-                if (names != null) {
-                    rl.setName(names.get(fi));
-                } else if (isDataURL) {
-                    rl.setName("Data");
-                }
-                if (indexFiles != null) {
-                    rl.setIndexPath(indexFiles.get(fi));
-                }
-                if (coverageFiles != null) {
-                    rl.setCoverage(coverageFiles.get(fi));
-                }
-                if (formats != null) {
-                    rl.setFormat(formats.get(fi));
+            if (!SessionReader.isSessionFile(fileString) && merge == false) {
+                igv.newSession();
+            }
+
+            // Create set of loaded files
+            Set<String> loadedFiles = new HashSet<>();
+            for (ResourceLocator rl : igv.getDataResourceLocators()) {
+                loadedFiles.add(rl.getPath());
+            }
+
+
+            // Loop through files
+            for (int fi = 0; fi < files.size(); fi++) {
+
+                String f = resolveFileReference(files.get(fi));
+
+                if (isDataURL && formats == null) {
+                    return "Error: format must be specified for dataURLs";
                 }
 
-                if (params != null) {
-                    String trackLine = createTrackLine(params);
-                    rl.setTrackLine(trackLine);
-                }
 
-                if (!isDataURL && rl.isLocal()) {
-                    File file = new File(rl.getPath());
-                    if (!file.exists()) {
-                        return "Error: " + f + " does not exist.";
+                // Skip already loaded files
+                if (!dup && loadedFiles.contains(f)) continue;
+
+                if (SessionReader.isSessionFile(f)) {
+                    igv.loadSession(f, locus);
+                } else {
+
+                    ResourceLocator rl = new ResourceLocator(f);
+
+                    if (names != null) {
+                        rl.setName(names.get(fi));
+                    } else if (isDataURL) {
+                        rl.setName("Data");
+                    }
+                    if (indexFiles != null) {
+                        rl.setIndexPath(indexFiles.get(fi));
+                    }
+                    if (coverageFiles != null) {
+                        rl.setCoverage(coverageFiles.get(fi));
+                    }
+                    if (formats != null) {
+                        rl.setFormat(formats.get(fi));
+                    }
+
+                    if (params != null) {
+                        String trackLine = createTrackLine(params);
+                        rl.setTrackLine(trackLine);
+                    }
+
+                    if (!isDataURL && rl.isLocal()) {
+                        File file = new File(rl.getPath());
+                        if (!file.exists()) {
+                            return "Error: " + f + " does not exist.";
+                        }
+                    }
+                    fileLocators.add(rl);
+                }
+            }
+
+
+            if (fileLocators.size() > 0) {
+                igv.loadTracks(fileLocators);
+            }
+
+
+            if (locus != null) {
+                igv.goToLocus(locus);
+            }
+
+            // Sort alignment tracks
+            if (igv.getAlignmentTracks().size() > 0) {
+
+                //If locus is a single base, and session has alignment tracks, provide default sort option (base)
+                if (locus != null && sort == null) {
+                    String[] tokens = locus.split(":", 2);
+                    if (tokens.length == 2 && !tokens[1].contains("-")) {
+                        // Sort by base by default
+                        sort = "base";
                     }
                 }
-                fileLocators.add(rl);
-            }
-        }
 
-
-        if (fileLocators.size() > 0) {
-            igv.loadTracks(fileLocators);
-        }
-
-        if (locus != null && !locus.equals("null")) {
-            igv.goToLocus(locus);
-            //If locus is a single base, we sort by base
-            String[] tokens = locus.split(":", 2);
-            if (tokens.length == 2) {
-                try {
-                    int pos = Integer.parseInt(tokens[1].replace(",", ""));
-                    if (pos >= 0 && sort == null) sort = "base";
-                } catch (Exception e) {
-                    //pass
+                if (sort != null) {
+                    final SortOption sortOption = getAlignmentSortOption(sort);
+                    igv.sortAlignmentTracks(sortOption, sortTag, false);
                 }
             }
-        }
 
-        if (sort != null) {
-            final AlignmentTrack.SortOption sortOption = getAlignmentSortOption(sort);
-            igv.sortAlignmentTracks(sortOption, sortTag);
+            return CommandListener.OK;
+        } finally {
+            Globals.setBatch(currentBatchSetting);
         }
+    }
 
-        return CommandListener.OK;
+    private String resolveFileReference(String f) {
+
+        if (FileUtils.isRemote(f)) {
+            return f;
+        } else {
+            File maybeFile = getFile(f);
+            if (maybeFile.exists()) {
+                f = maybeFile.getAbsolutePath();
+            }
+            return f;
+        }
     }
 
 
@@ -951,6 +959,7 @@ public class CommandExecutor {
      * @return
      */
     private File getFile(String path) {
+
         // Strip trailing & leading quotes
         path = StringUtils.stripQuotes(path);
 
@@ -1037,12 +1046,21 @@ public class CommandExecutor {
         } else {
             // Alignments
             String tag = null;
-            String locusString = null;
+            String locusString;
+            String reverseString;
             if (sortArg.equalsIgnoreCase("tag")) {
                 tag = param2;
                 locusString = param3;
+                reverseString = param4;
             } else {
                 locusString = param2;
+                reverseString = param3;
+            }
+
+            // Special case, "reverse" is a resered word for inverting sorting.  Locus is optional
+            if (reverseString == null && "reverse".equalsIgnoreCase(locusString)) {
+                reverseString = locusString;
+                locusString = null;
             }
 
             Double location = null;
@@ -1061,7 +1079,10 @@ public class CommandExecutor {
                     }
                 }
             }
-            igv.sortAlignmentTracks(getAlignmentSortOption(sortArg), location, tag);
+
+            boolean invertSort = "reverse".equalsIgnoreCase(reverseString);
+
+            igv.sortAlignmentTracks(getAlignmentSortOption(sortArg), location, tag, invertSort);
             return "OK";
         }
     }
@@ -1170,38 +1191,39 @@ public class CommandExecutor {
         }
     }
 
-    private static AlignmentTrack.SortOption getAlignmentSortOption(String str) {
+    //todo check that this matches all the existing sorts
+    private static SortOption getAlignmentSortOption(String str) {
         str = str == null ? "base" : str;
         if (str.equalsIgnoreCase("start") || str.equalsIgnoreCase("position")) {
-            return AlignmentTrack.SortOption.START;
+            return SortOption.START;
         } else if (str.equalsIgnoreCase("strand")) {
-            return AlignmentTrack.SortOption.STRAND;
+            return SortOption.STRAND;
         } else if (str.equalsIgnoreCase("base")) {
-            return AlignmentTrack.SortOption.NUCLEOTIDE;
+            return SortOption.NUCLEOTIDE;
         } else if (str.equalsIgnoreCase("quality")) {
-            return AlignmentTrack.SortOption.QUALITY;
+            return SortOption.QUALITY;
         } else if (str.equalsIgnoreCase("sample")) {
-            return AlignmentTrack.SortOption.SAMPLE;
+            return SortOption.SAMPLE;
         } else if (str.equalsIgnoreCase("readGroup") || str.equalsIgnoreCase("read_group")) {
-            return AlignmentTrack.SortOption.READ_GROUP;
+            return SortOption.READ_GROUP;
         } else if (str.equalsIgnoreCase("insertSize") || str.equalsIgnoreCase("insert_size")) {
-            return AlignmentTrack.SortOption.INSERT_SIZE;
+            return SortOption.INSERT_SIZE;
         } else if (str.equalsIgnoreCase("firstOfPairStrand")) {
-            return AlignmentTrack.SortOption.FIRST_OF_PAIR_STRAND;
+            return SortOption.FIRST_OF_PAIR_STRAND;
         } else if (str.equalsIgnoreCase("mateChr")) {
-            return AlignmentTrack.SortOption.MATE_CHR;
+            return SortOption.MATE_CHR;
         } else if (str.equalsIgnoreCase("readOrder")) {
-            return AlignmentTrack.SortOption.READ_ORDER;
+            return SortOption.READ_ORDER;
         } else if (str.equalsIgnoreCase("readname")) {
-            return AlignmentTrack.SortOption.READ_NAME;
+            return SortOption.READ_NAME;
         } else if (str.equalsIgnoreCase("alignedReadLength")) {
-            return AlignmentTrack.SortOption.ALIGNED_READ_LENGTH;
+            return SortOption.ALIGNED_READ_LENGTH;
         } else {
             try {
-                return AlignmentTrack.SortOption.valueOf(str.toUpperCase());
+                return SortOption.valueOf(str.toUpperCase());
             } catch (IllegalArgumentException e) {
                 log.error("Unknown sort option: " + str);
-                return AlignmentTrack.SortOption.NUCLEOTIDE;
+                return SortOption.NUCLEOTIDE;
             }
         }
 
