@@ -30,11 +30,14 @@ import org.broad.igv.logging.LogManager;
 import org.broad.igv.logging.Logger;
 import org.broad.igv.Globals;
 import org.broad.igv.feature.genome.GenomeManager;
-import org.broad.igv.google.OAuthUtils;
+import org.broad.igv.oauth.OAuthProvider;
+import org.broad.igv.oauth.OAuthUtils;
 import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.ui.IGV;
+import org.broad.igv.ui.util.MessageUtils;
 import org.broad.igv.ui.util.UIUtilities;
+import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.StringUtils;
 
 import java.awt.*;
@@ -178,7 +181,7 @@ public class CommandListener implements Runnable {
             while (!halt && (inputLine = in.readLine()) != null) {
 
                 String cmd = inputLine;
-                if(!cmd.contains("/oauthCallback")) {
+                if (!cmd.contains("/oauthCallback")) {
                     log.info(cmd);
                 }
 
@@ -218,15 +221,26 @@ public class CommandListener implements Runnable {
 
                             if (command != null) {
 
-                                // Detect google oauth callback
+                                // Detect  oauth callback
                                 if (command.equals("/oauthCallback")) {
-                                    if (params.containsKey("code")) {
-                                        OAuthUtils.getInstance().setAuthorizationCode(params);
+
+                                    OAuthProvider provider = OAuthUtils.getInstance().getProviderForState(params.get("state"));
+                                    if (params.containsKey("error")) {
+                                        sendTextResponse(out, "Error authorizing IGV: " + params.get("error"));
+                                    } else if (params.containsKey("code")) {
+                                        provider.setAuthorizationCode(params.get("code"));
+                                        sendTextResponse(out, "Authorization successful.  You may close this tab.");
                                     } else if (params.containsKey("token")) {
-                                        OAuthUtils.getInstance().setAccessToken(params);
+                                        // Very doubtful this is ever called -- its not a normal OAuth flow
+                                        log.info("Oauth token received");
+                                        provider.setAccessToken(params.get("token"));
+                                        sendTextResponse(out, "Authorization successful.  You may close this tab.");
+                                    } else {
+                                        sendTextResponse(out, "Unsuccessful authorization response: " + inputLine);
                                     }
-                                    sendTextResponse(out, "SUCCESS");
-                                    if(PreferencesManager.getPreferences().getAsBoolean(Constants.PORT_ENABLED) == false) {
+
+
+                                    if (PreferencesManager.getPreferences().getAsBoolean(Constants.PORT_ENABLED) == false) {
                                         // Turn off port
                                         halt();
                                     }
@@ -272,7 +286,6 @@ public class CommandListener implements Runnable {
         }
     }
 
-
     private void closeSockets() {
         if (clientSocket != null) {
             try {
@@ -382,8 +395,11 @@ public class CommandListener implements Runnable {
                 // Default for merge is "false" for session files,  "true" otherwise
                 boolean merge;
                 if (mergeValue != null) {
-                    // Explicit setting
-                    merge = mergeValue.equalsIgnoreCase("true");
+                    if ("ask".equals(mergeValue)) {
+                        merge = !MessageUtils.confirm("Unload current session before loading new tracks?");
+                    } else {
+                        merge = mergeValue.equalsIgnoreCase("true");
+                    }
                 } else if (file.endsWith(".xml") || file.endsWith(".php") || file.endsWith(".php3")) {
                     // Session file
                     merge = false;
@@ -399,7 +415,8 @@ public class CommandListener implements Runnable {
                 String coverage = params.get("coverage");
                 String sort = params.get("sort");
                 String sortTag = params.get("sortTag");
-                result = cmdExe.loadFiles(file, index, coverage, name, format, locus, merge, params, sort, sortTag);
+                boolean dup = "true".equals(params.get("dup"));
+                result = cmdExe.loadFiles(file, index, coverage, name, format, locus, merge, params, sort, sortTag, dup);
             } else {
                 result = "OK";  // No files, perhaps genome only
             }
@@ -417,8 +434,6 @@ public class CommandListener implements Runnable {
     }
 
 
-
-
     /**
      * Parse the html parameter string into a set of key-value pairs.  Parameter values are
      * url decoded with the exception of the "locus" parameter.
