@@ -27,7 +27,7 @@ package org.broad.igv.feature;
 
 //~--- non-JDK imports --------------------------------------------------------
 
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.renderer.GeneTrackRenderer;
 import org.broad.igv.track.FeatureCollectionSource;
@@ -307,7 +307,7 @@ public class EmblFeatureTableParser implements FeatureParser {
 
     static class EmblRecord {
 
-        private static Logger log = Logger.getLogger(EmblRecord.class);
+        private static Logger log = LogManager.getLogger(EmblRecord.class);
 
         boolean isNegative;
         private String type;
