@@ -1,6 +1,6 @@
 package org.broad.igv.feature.basepair;
 
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
 import org.broad.igv.feature.genome.*;
 import org.broad.igv.renderer.*;
 import org.broad.igv.session.Persistable;
@@ -27,7 +27,7 @@ import java.util.List;
 
 public class BasePairTrack extends AbstractTrack {
 
-    private static Logger log = Logger.getLogger(BasePairTrack.class);
+    private static Logger log = LogManager.getLogger(BasePairTrack.class);
 
     private BasePairRenderer basePairRenderer = new BasePairRenderer();
     private BasePairData basePairData = new BasePairData();
