@@ -137,7 +137,10 @@ final public class Constants {
     public static final String SAM_SAMPLING_WINDOW = "SAM.SAMPLING_WINDOW";
     public static final String SAM_DOWNSAMPLE_READS = "SAM.DOWNSAMPLE_READS";
     public static final String SAM_SORT_OPTION = "SAM.SORT_OPTION";
+    public static final String SAM_INVERT_SORT = "SAM.INVERT_SORT";
     public static final String SAM_GROUP_OPTION = "SAM.GROUP_OPTION";
+
+    public static final String SAM_GROUP_ALL = "SAM.GROUP_ALL";
     public static final String SAM_SHOW_ALL_BASES = "SAM.SHOW_ALL_BASES";
     public static final String SAM_SHOW_MISMATCHES = "SAM.SHOW_MISMATCHES";
     public static final String SAM_COLOR_BY = "SAM.COLOR_BY";
@@ -174,6 +177,8 @@ final public class Constants {
     public static final String SAM_DISPLAY_PAIRED = "SAM.DISPLAY_PAIRED";
     public static final String KNOWN_SNPS = "KNOWN_SNPS_FILE";
 
+    public static final String SMRT_KINETICS_SHOW_OPTIONS = "SMRT_KINETICS.SHOW_OPTIONS";
+
     // Sequence track settings
     public static final String SEQUENCE_TRANSLATION_STRAND = "SEQUENCE_TRANSLATION_STRAND";
     public static final String SHOW_SEQUENCE_TRANSLATION = "SHOW_SEQUENCE_TRANSLATION";
@@ -212,6 +217,8 @@ final public class Constants {
     public static final String OVERLAY_MUTATIONS_WHOLE_GENOME = "OVERLAY_MUTATIONS_WHOLE_GENOME";
     public static final String COLOR_MUTATIONS = "COVER_OVERLAY_KEY";
 
+    public static final String MUT_COORDS = "MUT_COORDS";
+
     // GWAS track options
     public static final String GWAS_TRACK_HEIGHT = "GWAS_TRACK_HEIGHT";
     public static final String GWAS_DESCRIPTION_CACHE_SIZE = "GWAS_DESCRIPTION_CACHE_SIZE";
