@@ -30,10 +30,14 @@
 package org.broad.igv.prefs;
 
 
-import org.apache.log4j.Logger;
 import org.broad.igv.DirectoryManager;
 import org.broad.igv.Globals;
+import org.broad.igv.batch.CommandListener;
+import org.broad.igv.event.AlignmentTrackEvent;
+import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.feature.genome.GenomeListItem;
+import org.broad.igv.logging.LogManager;
+import org.broad.igv.logging.Logger;
 import org.broad.igv.renderer.ColorScaleFactory;
 import org.broad.igv.renderer.ContinuousColorScale;
 import org.broad.igv.track.TrackType;
@@ -41,12 +45,11 @@ import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.color.ColorUtilities;
 import org.broad.igv.ui.color.PaletteColorTable;
-import org.broad.igv.event.AlignmentTrackEvent;
-import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.util.HttpUtils;
 
 import java.awt.*;
-import java.io.*;
+import java.io.File;
+import java.io.PrintWriter;
 import java.util.*;
 
 import static org.broad.igv.prefs.Constants.*;
@@ -56,11 +59,12 @@ import static org.broad.igv.prefs.Constants.*;
  */
 public class IGVPreferences {
 
-    private static Logger log = Logger.getLogger(IGVPreferences.class);
+    private static Logger log = LogManager.getLogger(IGVPreferences.class);
 
     IGVPreferences parent;
 
     Map<String, String> userPreferences;
+    Map<String, String> defaults;
     // Preferences which should persist for this session only
     Set<String> overrideKeys = new HashSet<>();
 
@@ -75,21 +79,25 @@ public class IGVPreferences {
     }
 
     public IGVPreferences(Map<String, String> userPreferences,
+                          Map<String, String> defaults,
                           IGVPreferences parent) {
         this.parent = parent;
+        this.defaults = defaults;
         this.userPreferences = userPreferences == null ? new HashMap<>() : userPreferences;
     }
 
     public String get(String key) {
         key = key.trim();
 
-        if(userPreferences.containsKey(key)) {
+        if (userPreferences.containsKey(key)) {
             return userPreferences.get(key);
-        }
-        else if(parent != null) {
+        } else if (parent != null && parent.userPreferences.containsKey(key)) {
+            return parent.userPreferences.get(key);
+        } else if (defaults != null && defaults.containsKey(key)) {
+            return defaults.get(key);
+        } else if (parent != null) {
             return parent.get(key);
-        }
-        else {
+        } else {
             return null;
         }
     }
@@ -98,6 +106,7 @@ public class IGVPreferences {
     /**
      * Return preference with given key and specified default value.  If key is not present defaultValue is returned,
      * no search through defaults or hierarchy is performed.
+     *
      * @param key
      * @param defaultValue
      * @return
@@ -109,7 +118,6 @@ public class IGVPreferences {
     }
 
 
-
     /**
      * Return the preference as a boolean value.
      *
@@ -123,10 +131,10 @@ public class IGVPreferences {
 
             String value = get(key);
             if (value == null) {
-                log.error("No default value for: " + key);
+                log.warn("No default value for: " + key);
                 return false;
             }
-            boolValue = new Boolean(get(key, value));
+            boolValue = Boolean.valueOf(get(key, value));
             booleanCache.put(key, boolValue);
         }
         return boolValue.booleanValue();
@@ -144,7 +152,7 @@ public class IGVPreferences {
         if (value == null) {
             String defValue = get(key);
             if (defValue == null) {
-                log.error("No default value for: " + key);
+                log.warn("No default value for: " + key);
                 return 0;
             }
             value = new Integer(get(key, defValue));
@@ -165,7 +173,7 @@ public class IGVPreferences {
         if (value == null) {
             String defValue = get(key);
             if (defValue == null) {
-                log.error("No default value for: " + key);
+                log.warn("No default value for: " + key);
                 return Color.white;
             }
             value = ColorUtilities.stringToColor(defValue);
@@ -186,7 +194,7 @@ public class IGVPreferences {
         if (value == null) {
             String defValue = get(key);
             if (defValue == null) {
-                log.error("No default value for: " + key);
+                log.warn("No default value for: " + key);
                 return 0;
             }
             value = new Float(get(key, defValue));
@@ -211,25 +219,11 @@ public class IGVPreferences {
         }
     }
 
-
     public boolean hasExplicitValue(String key) {
         key = key.trim();
         return userPreferences.containsKey(key);
     }
 
-    /**
-     * Get the default value for the specified key.
-     * May be null.
-     *
-     * @param key
-     * @return
-     */
-    public String getDefaultValue(String key) {
-        key = key.trim();
-        return parent == null ? get(key) : parent.get(key);
-    }
-
-
     public void addOverrides(Map<String, String> newPrefs) {
         overrideKeys.addAll(newPrefs.keySet());
         userPreferences.putAll(newPrefs);
@@ -237,16 +231,14 @@ public class IGVPreferences {
 
     public boolean getAntiAliasing() {
 
-        if(userPreferences.containsKey(Constants.ENABLE_ANTIALISING) || Globals.IS_LINUX == false) {
+        if (userPreferences.containsKey(Constants.ENABLE_ANTIALISING) || Globals.IS_LINUX == false) {
             return getAsBoolean(Constants.ENABLE_ANTIALISING);
-        }
-        else {
+        } else {
             // Linux with no explicit setting
             return false;
         }
     }
 
-
     /**
      * Update any cached values with the new key/value pair
      *
@@ -260,27 +252,37 @@ public class IGVPreferences {
         }
         colorScaleCache.remove(key);
         objectCache.remove(key);
+        mutationColorScheme = null;
     }
 
     private void clearCaches() {
         colorScaleCache.clear();
         booleanCache.clear();
         objectCache.clear();
+        mutationColorScheme = null;
     }
 
+    /**
+     * Update preference.  This command is ignored if in batch mode *
+     * @param key
+     * @param value
+     */
     public void put(String key, String value) {
-        key = key.trim();
 
-        // Explicitly setting removes override
-        overrideKeys.remove(key);
+        if (!Globals.isBatch()) {
+            key = key.trim();
 
-        if (value == null || value.trim().length() == 0) {
-            userPreferences.remove(key);
-        } else {
-            userPreferences.put(key, value);
+            // Explicitly setting removes override
+            overrideKeys.remove(key);
+
+            if (value == null || value.trim().length() == 0) {
+                userPreferences.remove(key);
+            } else {
+                userPreferences.put(key, value);
+            }
+            updateCaches(key, value);
+            IGVEventBus.getInstance().post(new PreferencesChangeEvent());
         }
-        updateCaches(key, value);
-        IGVEventBus.getInstance().post(new PreferencesChangeEvent());
     }
 
     public void put(String key, boolean b) {
@@ -297,7 +299,11 @@ public class IGVPreferences {
             }
         }
         clearCaches();
-        checkForAlignmentChanges(updatedPrefs);   // TODO replace with event
+        checkForProxyChanges(updatedPrefs);
+        checkForAlignmentChanges(updatedPrefs);
+        checkForCommandListenerChanges(updatedPrefs);
+        checkForAttributePanelChanges(updatedPrefs);
+        checkForCircViewChanges(updatedPrefs);
         IGVEventBus.getInstance().post(new PreferencesChangeEvent());
 
     }
@@ -338,6 +344,46 @@ public class IGVPreferences {
 
     }
 
+    private void checkForProxyChanges(Map<String, String> updatedPreferenceMap) {
+        if (HttpUtils.getInstance() != null) {
+            for (String key : PROXY_KEYS) {
+                if (updatedPreferenceMap.containsKey(key)) {
+                    HttpUtils.getInstance().updateProxySettings();
+                    break;
+                }
+            }
+        }
+    }
+
+    private void checkForCommandListenerChanges(Map<String, String> updatedPreferenceMap) {
+        if (updatedPreferenceMap.containsKey(PORT_ENABLED) || updatedPreferenceMap.containsKey(PORT_NUMBER)) {
+            CommandListener.halt();
+            if (getAsBoolean(PORT_ENABLED)) {
+                CommandListener.start(getAsInt(PORT_NUMBER));
+            }
+        }
+    }
+
+    private void checkForAttributePanelChanges(Map<String, String> updatedPreferenceMap) {
+        if (updatedPreferenceMap.containsKey(SHOW_ATTRIBUTE_VIEWS_KEY) || updatedPreferenceMap.containsKey(SHOW_DEFAULT_TRACK_ATTRIBUTES)) {
+            if (IGV.hasInstance()) {
+                IGV.getInstance().revalidateTrackPanels();
+            }
+        }
+    }
+
+    /**
+     * Enabling circ view requires port listener
+     */
+    private void checkForCircViewChanges(Map<String, String> updatedPreferenceMap) {
+        if (updatedPreferenceMap.containsKey(CIRC_VIEW_ENABLED) &&
+                getAsBoolean(CIRC_VIEW_ENABLED) &&
+                !getAsBoolean(PORT_ENABLED)) {
+            put(PORT_ENABLED, true);
+            CommandListener.start(getAsInt(PORT_NUMBER));
+        }
+    }
+
 
     public void remove(String key) {
         overrideKeys.remove(key);
@@ -363,6 +409,14 @@ public class IGVPreferences {
         return get(GENOMES_SERVER_URL);
     }
 
+    public String getProvisioningURL() {
+        return get(PROVISIONING_URL);
+    }
+
+    public String getPortNumber() {
+        return get(PORT_NUMBER);
+    }
+
     public void overrideGenomeServerURL(String url) {
         userPreferences.put(GENOMES_SERVER_URL, url);
         overrideKeys.add(GENOMES_SERVER_URL);
@@ -398,9 +452,9 @@ public class IGVPreferences {
     /**
      * @param directory
      */
-    public void setLastSnapshotDirectory(File directory) {
+    public void setLastSnapshotDirectory(String directory) {
 
-        put(LAST_SNAPSHOT_DIRECTORY, directory.getAbsolutePath());
+        put(LAST_SNAPSHOT_DIRECTORY, directory);
     }
 
     /**
@@ -523,7 +577,6 @@ public class IGVPreferences {
 
 
     public String getRecentSessions() {
-
         return get(RECENT_SESSIONS, null);
     }
 
@@ -553,7 +606,7 @@ public class IGVPreferences {
      */
     public void override(String key, String value) {
         userPreferences.put(key, value);
-        overrideKeys.add(key);
+        overrideKeys.add(key);    // <= order here is important, must be after userPreferences statement
         Map<String, String> updatedPrefs = new HashMap<String, String>();
         updatedPrefs.put(key, value);
         checkForAlignmentChanges(updatedPrefs);
@@ -776,6 +829,27 @@ public class IGVPreferences {
         return colorTable;
     }
 
+    static String getMutationColorKey(String type) {
+        switch (type) {
+            case "Indel":
+                return MUTATION_INDEL_COLOR_KEY;
+            case "Missense":
+                return MUTATION_MISSENSE_COLOR_KEY;
+            case "Nonsense":
+                return MUTATION_NONSENSE_COLOR_KEY;
+            case "Splice_site":
+                return MUTATION_SPLICE_SITE_COLOR_KEY;
+            case "Synonymous":
+                return MUTATION_SYNONYMOUS_COLOR_KEY;
+            case "Targeted_region":
+                return MUTATION_TARGETED_REGION_COLOR_KEY;
+            case "Unknown":
+                return MUTATION_UNKNOWN_COLOR_KEY;
+            default:
+                return "MUTATION_" + type + "_COLOR";
+        }
+    }
+
 
     /**
      * Immediately clear all proxy settings.
@@ -893,11 +967,13 @@ public class IGVPreferences {
 
     public void print(PrintWriter pw) {
         for (Map.Entry<String, String> entry : userPreferences.entrySet()) {
-            pw.print(entry.getKey());
-            pw.print("=");
-            pw.println(entry.getValue());
+            if (!overrideKeys.contains(entry.getKey())) {
+                pw.print(entry.getKey());
+                pw.print("=");
+                pw.println(entry.getValue());
+            }
         }
     }
-    
+
 
 }
