@@ -38,8 +38,8 @@ import org.broad.igv.renderer.GraphicUtils;
 import org.broad.igv.renderer.SequenceRenderer;
 import org.broad.igv.sam.AlignmentTrack.ColorOption;
 import org.broad.igv.sam.BisulfiteBaseInfo.DisplayStatus;
-import org.broad.igv.sam.mods.BaseModificationUtils;
-import org.broad.igv.sam.mods.BaseModificationSet;
+import org.broad.igv.sam.mods.BaseModificationRenderer;
+import org.broad.igv.sam.smrt.SMRTKineticsRenderer;
 import org.broad.igv.track.RenderContext;
 import org.broad.igv.track.Track;
 import org.broad.igv.ui.FontManager;
@@ -63,6 +63,12 @@ public class AlignmentRenderer {
 
     private static final Color negStrandColor = new Color(150, 150, 230);
     private static final Color posStrandColor = new Color(230, 150, 150);
+
+    private static final Color firstOfPairColor = new Color(150, 150, 230);
+    private static final Color secondOfPairColor = new Color(230, 150, 150);
+    private static final Color firstAndSecondofPairColor = new Color(150, 150, 0);
+    private static final Color neitherForOrSecondOfPair = new Color(198, 106, 245, 255);
+
     private static final Color RL_COLOR = new Color(0, 150, 0);
     private static final Color RR_COLOR = new Color(20, 50, 200);
     private static final Color LL_COLOR = new Color(0, 150, 150);
@@ -310,10 +316,11 @@ public class AlignmentRenderer {
                 double pixelWidth = pixelEnd - pixelStart;
                 Color alignmentColor = getAlignmentColor(alignment, track);
                 final boolean leaveMargin = (this.track.getDisplayMode() != Track.DisplayMode.SQUISHED);
+                final ColorOption colorOption = renderOptions.getColorOption();
                 if ((pixelWidth < 2) &&
-                        !((AlignmentTrack.isBisulfiteColorType(renderOptions.getColorOption()) ||
-                                renderOptions.getColorOption() == ColorOption.BASE_MODIFICATION ||
-                                renderOptions.getColorOption() == ColorOption.BASE_MODIFICATION_5MC) &&
+                        !((AlignmentTrack.isBisulfiteColorType(colorOption) ||
+                                colorOption.isBaseMod() ||
+                                colorOption.isSMRTKinetics()) &&
                                 (pixelWidth >= 1))) {
                     // Optimization for really zoomed out views.  If this alignment occupies screen space already taken,
                     // and it is the default color, skip drawing.
@@ -635,7 +642,7 @@ public class AlignmentRenderer {
         // Draw blocks
         // Get a graphics context for outlining alignment blocks.
         Graphics2D outlineGraphics = null;
-        final HashMap<String, Color> selectedReadNames = this.track.selectedReadNames;
+        final HashMap<String, Color> selectedReadNames = this.track.getSelectedReadNames();
         if (selectedReadNames.containsKey(alignment.getReadName())) {
             Color c = selectedReadNames.get(alignment.getReadName());
             c = (c == null) ? Color.blue : c;
@@ -781,10 +788,20 @@ public class AlignmentRenderer {
                                 (bisulfiteMode && (DisplayStatus.NOTHING != bisinfo.getDisplayStatus(idx)))) {
                             char c = (char) blockBases.getByte(idx);
 
+                            double bisulfiteXaxisShift = (bisulfiteMode) ? bisinfo.getXaxisShift(idx) : 0;
+                            int pX = (int) (((double) loc + bisulfiteXaxisShift - bpStart) / locScale);
+
+                            // Don't draw out of clipping rect
+                            if (pX > rowRect.getMaxX()) {
+                                break;
+                            } else if (pX + dX < rowRect.getX()) {
+                                continue;
+                            }
                             Color color = null;
                             if (bisulfiteMode) {
                                 color = bisinfo.getDisplayColor(idx);
-                            } else if (colorOption == ColorOption.BASE_MODIFICATION || colorOption == ColorOption.BASE_MODIFICATION_5MC) {
+                            } else if (colorOption.isBaseMod() ||
+                                       colorOption.isSMRTKinetics()) {
                                 color = Color.GRAY;
                             } else {
                                 color = nucleotideColors.get(c);
@@ -798,19 +815,6 @@ public class AlignmentRenderer {
                                 color = getShadedColor(qual, color, alignmentColor, prefs);
                             }
 
-                            double bisulfiteXaxisShift = (bisulfiteMode) ? bisinfo.getXaxisShift(idx) : 0;
-
-                            // If there is room for text draw the character, otherwise
-                            // just draw a rectangle to represent the
-                            int pX = (int) (((double) loc + bisulfiteXaxisShift - bpStart) / locScale);
-
-                            // Don't draw out of clipping rect
-                            if (pX > rowRect.getMaxX()) {
-                                break;
-                            } else if (pX + dX < rowRect.getX()) {
-                                continue;
-                            }
-
                             BisulfiteBaseInfo.DisplayStatus bisstatus = (bisinfo == null) ? null : bisinfo.getDisplayStatus(idx);
 
                             final boolean showBase =
@@ -827,108 +831,15 @@ public class AlignmentRenderer {
             }
         }
 
-
         // Base modification
-        if (ColorOption.BASE_MODIFICATION_5MC == colorOption || ColorOption.BASE_MODIFICATION == colorOption) {
-
-            List<BaseModificationSet> baseModificationSets = alignment.getBaseModificationSets();
-            if (baseModificationSets != null) {
-
-                for (AlignmentBlock block : alignment.getAlignmentBlocks()) {
-                    // Compute bounds
-                    int pY = (int) rowRect.getY();
-                    int dY = (int) rowRect.getHeight();
-                    dX = (int) Math.max(1, (1.0 / locScale));
-                    Graphics g = context.getGraphics();
-
-                    for (int i = block.getBases().startOffset; i < block.getBases().startOffset + block.getBases().length; i++) {
-
-                        // Search all sets for modifications of this base.  For now keeps mod with > probability
-                        // TODO -- merge mods in some way
-                        byte lh = 0;
-                        String modification = null;
-                        for (BaseModificationSet bmSet : baseModificationSets) {
-                            if (bmSet.containsPosition(i)) {
-                                if(modification == null || bmSet.getLikelihoods().get(i) > lh) {
-                                    modification = bmSet.getModification();
-                                    lh = bmSet.getLikelihoods().get(i);
-                                }
-                            }
-                        }
-
-
-                        if (modification != null) {
-
-                            Color c = BaseModificationUtils.getModColor(modification, lh, colorOption);
-                            g.setColor(c);
-
-                            int blockIdx = i - block.getBases().startOffset;
-                            int pX = (int) ((block.getStart() + blockIdx - bpStart) / locScale);
-
-                            // Don't draw out of clipping rect
-                            if (pX > rowRect.getMaxX()) {
-                                break;
-                            } else if (pX + dX < rowRect.getX()) {
-                                continue;
-                            }
-
-                            // Expand narrow width to make more visible
-                            if (dX < 3) {
-                                dX = 3;
-                                pX--;
-                            }
-                            g.fillRect(pX, pY, dX, Math.max(1, dY - 2));
-                        }
-                    }
-                }
-            }
+        if (colorOption.isBaseMod()) {
+            BaseModificationRenderer.drawModifications(alignment, bpStart, locScale, rowRect, context.getGraphics(), colorOption);
         }
 
-//        if (renderOptions.getColorOption() == ColorOption.BASE_MODIFICATION) {
-//            Map<Integer, BaseModification> baseModifications = alignment.getBaseModificationMap();
-//            if (baseModifications != null) {
-//                double threshold = 256 * PreferencesManager.getPreferences().getAsFloat("SAM.BASEMOD_THRESHOLD");
-//                for (AlignmentBlock block : alignment.getAlignmentBlocks()) {
-//                    // Compute bounds
-//                    int pY = (int) rowRect.getY();
-//                    int dY = (int) rowRect.getHeight();
-//                    dX = (int) Math.max(1, (1.0 / locScale));
-//                    Graphics g = context.getGraphics();
-//
-//                    for (int i = block.getBases().startOffset; i < block.getBases().startOffset + block.getBases().length; i++) {
-//
-//                        if (baseModifications.containsKey(i)) {
-//
-//                            BaseModification mod = baseModifications.get(i);
-//                            int l = Byte.toUnsignedInt(mod.likelihood);
-//                            if (l < threshold) continue;
-//
-//                            Color c = BaseModification.getModColor(mod.modification, mod.likelihood);
-//                            g.setColor(c);
-//
-//                            int blockIdx = i - block.getBases().startOffset;
-//                            int pX = (int) ((block.getStart() + blockIdx - bpStart) / locScale);
-//
-//                            // Don't draw out of clipping rect
-//                            if (pX > rowRect.getMaxX()) {
-//                                break;
-//                            } else if (pX + dX < rowRect.getX()) {
-//                                continue;
-//                            }
-//
-//                            // Expand narrow width to make more visible
-//                            if (dX < 3) {
-//                                dX = 3;
-//                                pX--;
-//                            }
-//
-//                            g.fillRect(pX, pY, dX, Math.max(1, dY - 2));
-//                        }
-//                    }
-//                }
-//            }
-//        }
-//
+        // Kinetic data
+        if (colorOption.isSMRTKinetics()) {
+            SMRTKineticsRenderer.drawSmrtKinetics(alignment, bpStart, locScale, rowRect, context.getGraphics(), colorOption);
+        }
 
         // DRAW Insertions
         AlignmentBlock[] insertions = alignment.getInsertions();
@@ -1043,6 +954,7 @@ public class AlignmentRenderer {
         return color;
     }
 
+
     private void drawLargeIndelLabel(Graphics2D g, boolean isInsertion, String labelText, int pxCenter,
                                      int pxTop, int pxH, int pxWmax, int translateX, AlignmentBlock insertionBlock) {
 
@@ -1256,7 +1168,7 @@ public class AlignmentRenderer {
 
         Color defaultColor = track.getColor();
         Color c = defaultColor;
-        AlignmentTrack.RenderOptions renderOptions = track.renderOptions;
+        AlignmentTrack.RenderOptions renderOptions = track.getRenderOptions();
         ColorOption colorOption = renderOptions.getColorOption();
         String readNameParts[];
 
@@ -1273,6 +1185,13 @@ public class AlignmentRenderer {
             case BISULFITE:
             case BASE_MODIFICATION:
             case BASE_MODIFICATION_5MC:
+            case BASE_MODIFICATION_C:
+            case SMRT_SUBREAD_IPD:
+            case SMRT_SUBREAD_PW:
+            case SMRT_CCS_FWD_IPD:
+            case SMRT_CCS_FWD_PW:
+            case SMRT_CCS_REV_IPD:
+            case SMRT_CCS_REV_PW:
                 // Just a simple forward/reverse strand color scheme that won't clash with the
                 // methylation rectangles.
                 c = (alignment.getFirstOfPairStrand() == Strand.POSITIVE) ? bisulfiteColorFw1 : bisulfiteColorRev1;
@@ -1345,6 +1264,19 @@ public class AlignmentRenderer {
                     c = posStrandColor;
                 }
                 break;
+            case READ_ORDER:
+                if (alignment.isPaired()){
+                    if(alignment.isFirstOfPair() && !alignment.isSecondOfPair()){
+                        c = firstOfPairColor;
+                    } else if(!alignment.isFirstOfPair() && alignment.isSecondOfPair()) {
+                        c = secondOfPairColor;
+                    } else if (alignment.isFirstOfPair() && alignment.isSecondOfPair()) {
+                        c = firstAndSecondofPairColor;
+                    } else {
+                        c = neitherForOrSecondOfPair;
+                    }
+                }
+                break;
             case READ_GROUP:
                 String rg = alignment.getReadGroup();
                 if (rg != null) {
