@@ -41,6 +41,8 @@ import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.sam.mods.BaseModificationUtils;
 import org.broad.igv.sam.mods.BaseModificationSet;
+import org.broad.igv.sam.smrt.SMRTKinetics;
+import org.broad.igv.sam.smrt.SMRTKineticsDecoder;
 import org.broad.igv.ui.color.ColorUtilities;
 
 import java.awt.*;
@@ -103,16 +105,16 @@ public class SAMAlignment implements Alignment {
     public AlignmentBlockImpl[] insertions;
     List<Gap> gaps;
     char[] gapTypes;
+    protected String mateSequence = null;
+    protected String pairOrientation = "";
+    private Strand firstOfPairStrand;
+    private Strand secondOfPairStrand;
 
     /**
      * Map of position -> base modification
      */
     private List<BaseModificationSet> baseModificationSets;
-
-    protected String mateSequence = null;
-    protected String pairOrientation = "";
-    private Strand firstOfPairStrand;
-    private Strand secondOfPairStrand;
+    private SMRTKinetics smrtKinetics;
 
     public SAMAlignment(SAMRecord record) {
 
@@ -157,7 +159,6 @@ public class SAMAlignment implements Alignment {
         setPairOrientation();
         setPairStrands();
         createAlignmentBlocks();
-
     }
 
     public SAMRecord getRecord() {
@@ -340,6 +341,13 @@ public class SAMAlignment implements Alignment {
         return baseModificationSets;
     }
 
+    public SMRTKinetics getSmrtKinetics() {
+        if (smrtKinetics == null) {
+            smrtKinetics = new SMRTKinetics(this);
+        }
+        return smrtKinetics;
+    }
+
     /**
      * Set pair strands.  Used for strand specific libraries to recover strand of
      * originating fragment.
@@ -379,6 +387,26 @@ public class SAMAlignment implements Alignment {
         }
     }
 
+    /**
+     * Return the number of bases hard-clipped from the leading-edge (leftmost view in IGV) of the alignment
+     */
+    public int getLeadingHardClipLength() {
+        int clipLength = 0;
+
+        String cigarString = record.getCigarString();
+        if (!cigarString.equals("*")) {
+            java.util.List<CigarOperator> operators = buildOperators(cigarString);
+            for (CigarOperator operator : operators) {
+                if (operator.operator == HARD_CLIP) {
+                    clipLength += operator.nBases;
+                } else {
+                    break;
+                }
+            }
+        }
+        return clipLength;
+    }
+
     /**
      * Create the alignment blocks from the read bases and alignment information in the CIGAR
      * string.  The CIGAR string encodes insertions, deletions, skipped regions, and padding.
@@ -579,6 +607,14 @@ public class SAMAlignment implements Alignment {
         return getAlignmentValueString(location, mouseX, (AlignmentTrack.RenderOptions) null);
     }
 
+    private Integer positionToReadIndex(double position) {
+        for (AlignmentBlock block : this.alignmentBlocks) {
+            if (block.contains((int) position)) {
+                return (int) (position - block.getStart()) + block.getBasesOffset();
+            }
+        }
+        return null;
+    }
 
     public String getAlignmentValueString(double position, int mouseX, AlignmentTrack.RenderOptions renderOptions) {
 
@@ -591,50 +627,88 @@ public class SAMAlignment implements Alignment {
             buf.append("Dist: " + getHapDistance() + "<br>");
         }
 
+        boolean atInsertion = false;
+        boolean atBaseMod = false;
         // First check insertions.  Position is zero based, block coords 1 based
         if (this.insertions != null) {
             for (AlignmentBlock block : this.insertions) {
                 if (block.containsPixel(mouseX)) {
                     ByteSubarray bases = block.getBases();
                     if (bases == null) {
-                        buf.append("Insertion: " + block.getLength() + " bases");
+                        buf.append("Insertion: " + block.getLength() + " bases<br>");
                     } else {
                         if (bases.length < 50) {
-                            buf.append("Insertion (" + bases.length + " bases): " + bases.getString());
+                            buf.append("Insertion (" + bases.length + " bases): " + bases.getString() + "<br>");
                         } else {
                             int len = bases.length;
                             buf.append("Insertion (" + bases.length + " bases): " + new String(bases.copyOfRange(0, 25)) + "..." +
-                                    new String(bases.copyOfRange(len - 25, len)));
+                                    new String(bases.copyOfRange(len - 25, len)) + "<br>");
                         }
                     }
-                    return buf.toString();
+                    atInsertion = true;
                 }
             }
         }
 
-        // Check base modifications
-        if (renderOptions != null &&
-                (renderOptions.getColorOption() == AlignmentTrack.ColorOption.BASE_MODIFICATION ||
-                        renderOptions.getColorOption() == AlignmentTrack.ColorOption.BASE_MODIFICATION_5MC)) {
-            for (AlignmentBlock block : this.alignmentBlocks) {
-                if (block.contains((int) position)) {
-                    int p = (int) (position - block.getStart()) + block.getBasesOffset();
+        // Check base modifications & kinetics
+        if (renderOptions != null) {
+            final AlignmentTrack.ColorOption colorOption = renderOptions.getColorOption();
+            if (colorOption.isBaseMod()) {
+                Integer readIndex = positionToReadIndex(position);
+                if (readIndex != null) {
+                    int p = readIndex;
                     if (baseModificationSets != null) {
                         String modString = "";
                         for (BaseModificationSet bmSet : baseModificationSets) {
                             if (bmSet.containsPosition(p)) {
-                                if (modString.length() > 0) modString += "; ";
+                                if (modString.length() > 0) modString += "<br>";
                                 modString += BaseModificationUtils.valueString(bmSet.getModification(), bmSet.getLikelihoods().get(p));
                             }
                         }
                         if (modString.length() > 0) {
-                            return modString;
+                            buf.append(modString);
+                            buf.append("<br");
+                            atBaseMod = true;
+                        }
+                    }
+                }
+            } else if (colorOption.isSMRTKinetics()) {
+                Integer readIndex = positionToReadIndex(position);
+                SMRTKinetics sk = getSmrtKinetics();
+                if (readIndex != null) {
+                    if (colorOption == AlignmentTrack.ColorOption.SMRT_SUBREAD_IPD) {
+                        short[] ipdVals = sk.getSmrtSubreadIpd();
+                        if (ipdVals != null) {
+                            return "Subread IPD: " + Short.toUnsignedInt(ipdVals[readIndex]) + " Frames";
+                        }
+                    } else if (colorOption == AlignmentTrack.ColorOption.SMRT_SUBREAD_PW) {
+                        short[] pwVals = sk.getSmrtSubreadPw();
+                        if (pwVals != null) {
+                            return "Subread PW: " + Short.toUnsignedInt(pwVals[readIndex]) + " Frames";
+                        }
+                    } else if (colorOption == AlignmentTrack.ColorOption.SMRT_CCS_FWD_IPD || colorOption == AlignmentTrack.ColorOption.SMRT_CCS_REV_IPD) {
+                        final boolean isForwardStrand = (colorOption == AlignmentTrack.ColorOption.SMRT_CCS_FWD_IPD);
+                        short[] ipdVals = sk.getSmrtCcsIpd(isForwardStrand);
+                        if (ipdVals != null) {
+                            final String strand = (isForwardStrand ? "fwd" : "rev");
+                            return "CCS " + strand + "-strand aligned IPD: " + Short.toUnsignedInt(ipdVals[readIndex]) + " Frames";
+                        }
+                    } else {
+                        final boolean isForwardStrand = (colorOption == AlignmentTrack.ColorOption.SMRT_CCS_FWD_PW);
+                        short[] pwVals = sk.getSmrtCcsPw(isForwardStrand);
+                        if (pwVals != null) {
+                            final String strand = (isForwardStrand ? "fwd" : "rev");
+                            return "CCS " + strand + "-strand aligned PW: " + Short.toUnsignedInt(pwVals[readIndex]) + " Frames";
                         }
                     }
                 }
             }
         }
 
+        if (atInsertion || atBaseMod) {
+            return buf.toString();
+        }
+
         buf.append("Read name = " + getReadName() + "<br>");
 
         String sample = getSample();
@@ -925,7 +999,7 @@ public class SAMAlignment implements Alignment {
     public AlignmentBlock getInsertionAt(int position) {
         for (AlignmentBlock block : insertions) {
             if (block.getStart() == position) return block;
-            if (block.getStart() > position) return null;  // Blocks increase lineraly
+            if (block.getStart() > position) return null;  // Blocks increase linearly
         }
         return null;
     }
