@@ -5,7 +5,11 @@ import org.broad.igv.ui.panel.Paintable;
 import javax.swing.*;
 import java.awt.*;
 
-public class SashimiContentPane extends JPanel implements Paintable {
+public class SashimiContentPane extends JSplitPane implements Paintable {
+
+    public SashimiContentPane(JPanel sashimiPanel, JScrollPane scrollableGenePane) {
+        super(JSplitPane.VERTICAL_SPLIT, sashimiPanel, scrollableGenePane);
+    }
 
     @Override
     public void paintOffscreen(Graphics2D g, Rectangle rect, boolean batch) {
