@@ -110,6 +110,8 @@ public class IGVSessionReader implements SessionReader {
      */
     private final Map<String, List<Track>> allTracks = Collections.synchronizedMap(new LinkedHashMap<>());
 
+    private final Set<String> erroredResources = Collections.synchronizedSet(new HashSet<>());
+
     public List<Track> getTracksById(String trackId) {
         List<Track> tracks = allTracks.get(trackId);
         if (tracks == null) {
@@ -466,6 +468,7 @@ public class IGVSessionReader implements SessionReader {
                             trackList.add(track);
                         }
                     } catch (Exception e) {
+                        erroredResources.add(locator.getPath());
                         log.error("Error loading resource " + locator.getPath(), e);
                         String ms = "<b>" + locator.getPath() + "</b><br>&nbsp;&nbsp;" + e.toString() + "<br>";
                         errors.add(ms);
@@ -580,7 +583,7 @@ public class IGVSessionReader implements SessionReader {
         if (infolink == null) {
             infolink = getAttribute(element, SessionAttribute.INFOLINK);
         }
-        resourceLocator.setTrackInforURL(infolink);
+        resourceLocator.setTrackInfoURL(infolink);
 
 
         // Label is deprecated in favor of name.
@@ -907,51 +910,60 @@ public class IGVSessionReader implements SessionReader {
             }
             leftoverTrackDictionary.remove(id);
         } else {
-            // No match found, element represents a track not created from "Resource" or genome load.  These include
+            // No match found, element represents either (1) a track from a file that errored during load, for example
+            // a file that has been deleted, or (2) a track not created from "Resource" or genome load.  These include
             // reference sequence, combined,  and merged tracks.
+
+            // Check for errors during load
+//            String absPath = getAbsolutePath(id, rootPath);
+//            if (erroredResources.contains(id) || erroredResources.contains(absPath)) {
+//                return Collections.emptyList();
+//            }
+
+//            String className = getAttribute(element, "clazz");
+//            if (className != null &&
+//                    (className.contains("MergedTracks") ||
+//                            className.contains("CombinedDataTrack") ||
+//                            className.contains("SequenceTrack") ||
+//                            className.contains("BlatTrack"))) {
             String className = getAttribute(element, "clazz");
-            if (className != null) {
-                try {
+            try {
+                Track track = createTrack(className, element);
+                if (track != null) {
 
-                    Track track = createTrack(className, element);
-                    if (track != null) {
+                    track.unmarshalXML(element, version);
+                    matchedTracks = Arrays.asList(track);
+                    allTracks.put(track.getId(), matchedTracks);   // Important for second pass
 
-                        track.unmarshalXML(element, version);
-                        matchedTracks = Arrays.asList(track);
-                        allTracks.put(track.getId(), matchedTracks);   // Important for second pass
-
-                        // Special tracks
-                        if (className.contains("CombinedDataTrack")) {
-                            combinedDataSourceTracks.add(new Pair(track, element));
-                        }
-
-                        if (className.contains("MergedTracks")) {
-                            List<DataTrack> memberTracks = processChildTracks(session, element, additionalInformation, rootPath);
-                            ((MergedTracks) track).setMemberTracks(memberTracks);
-
-                            NodeList nodeList = element.getElementsByTagName("DataRange");
-                            if (nodeList != null && nodeList.getLength() > 0) {
-                                Element dataRangeElement = (Element) nodeList.item(0);
-                                try {
-                                    DataRange dataRange = new DataRange(dataRangeElement, version);
-                                    track.setDataRange(dataRange);
-                                } catch (Exception e) {
-                                    log.error("Unrecognized DataRange");
-                                }
-                            }
-
-                        }
-
-
-                    } else {
-                        log.warn("Warning.  No tracks were found with id: " + id + " in session file");
+                    // Special tracks
+                    if (className.contains("CombinedDataTrack")) {
+                        combinedDataSourceTracks.add(new Pair(track, element));
                     }
-                } catch (Exception e) {
-                    log.error("Error restoring track: " + element.toString(), e);
-                    MessageUtils.showMessage("Error loading track: " + element.toString());
+
+                    if (className.contains("MergedTracks")) {
+                        List<DataTrack> memberTracks = processChildTracks(session, element, additionalInformation, rootPath);
+                        ((MergedTracks) track).setMemberTracks(memberTracks);
+
+                        NodeList nodeList = element.getElementsByTagName("DataRange");
+                        if (nodeList != null && nodeList.getLength() > 0) {
+                            Element dataRangeElement = (Element) nodeList.item(0);
+                            try {
+                                DataRange dataRange = new DataRange(dataRangeElement, version);
+                                track.setDataRange(dataRange);
+                            } catch (Exception e) {
+                                log.error("Unrecognized DataRange");
+                            }
+                        }
+                    }
+                } else {
+                    log.warn("Warning.  No tracks were found with id: " + id + " in session file");
                 }
+            } catch (Exception e) {
+                log.error("Error restoring track: " + element.toString(), e);
+                MessageUtils.showMessage("Error loading track: " + element.toString());
             }
         }
+        //}
 
         NodeList elements = element.getChildNodes();
         process(session, elements, additionalInformation, rootPath);
