@@ -29,7 +29,7 @@
  */
 package org.broad.igv.tdf;
 
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
 import org.broad.igv.Globals;
 import org.broad.igv.data.BasicScore;
 import org.broad.igv.data.CompositeScore;
@@ -50,7 +50,7 @@ import java.util.*;
  */
 public class TDFDataSource implements CoverageDataSource {
 
-    private static Logger log = Logger.getLogger(TDFDataSource.class);
+    private static Logger log = LogManager.getLogger(TDFDataSource.class);
 
     TDFReader reader;
     int maxPrecomputedZoom = 6;
@@ -439,21 +439,20 @@ public class TDFDataSource implements CoverageDataSource {
                 tileWidth = chromosome.getLength() / ((int) Math.pow(2.0, zoom));
             }
         }
-        if (tileWidth == 0) {
-            return null;
-        }
 
-        int startTile = (startLocation / tileWidth);
-        int endTile = ((endLocation - 1) / tileWidth);
+        if (tileWidth > 0) {
+            int startTile = (startLocation / tileWidth);
+            int endTile = ((endLocation - 1) / tileWidth);
 
-        for (int t = startTile; t <= endTile; t++) {
-            List<LocusScore> cachedScores = getCachedSummaryScores(querySeq, zoom, t, tileWidth);
-            if (cachedScores != null) {
-                for (LocusScore s : cachedScores) {
-                    if (s.getEnd() >= startLocation) {
-                        scores.add(s);
-                    } else if (s.getStart() > endLocation) {
-                        break;
+            for (int t = startTile; t <= endTile; t++) {
+                List<LocusScore> cachedScores = getCachedSummaryScores(querySeq, zoom, t, tileWidth);
+                if (cachedScores != null) {
+                    for (LocusScore s : cachedScores) {
+                        if (s.getEnd() >= startLocation) {
+                            scores.add(s);
+                        } else if (s.getStart() > endLocation) {
+                            break;
+                        }
                     }
                 }
             }
