@@ -26,7 +26,7 @@
 package org.broad.igv.tools;
 
 import htsjdk.samtools.util.CloseableIterator;
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
 import org.broad.igv.feature.Chromosome;
 import org.broad.igv.feature.Locus;
 import org.broad.igv.feature.Strand;
@@ -45,7 +45,7 @@ import java.util.*;
  */
 public class CoverageCounter {
 
-    static private Logger log = Logger.getLogger(CoverageCounter.class);
+    static private Logger log = LogManager.getLogger(CoverageCounter.class);
 
     /**
      * The path to the alignment file being counted.
@@ -346,7 +346,7 @@ public class CoverageCounter {
                     if (blocks != null && !pairedCoverage) {
                         for (AlignmentBlock block : blocks) {
 
-                            if (!block.isSoftClipped()) {
+                            if (!block.isSoftClip()) {
 
                                 int blockStart = block.getStart();
                                 int blockEnd = block.getEnd();
@@ -387,17 +387,19 @@ public class CoverageCounter {
                                     adjustedEnd = Math.min(queryInterval.getEnd(), adjustedEnd);
                                 }
 
-                                byte[] bases = block.getBases();
-                                for (int pos = adjustedStart; pos < adjustedEnd; pos++) {
-                                    byte base = 0;
-                                    int baseIdx = pos - blockStart;
-                                    if (bases != null && baseIdx >= 0 && baseIdx < bases.length) {
-                                        base = bases[baseIdx];
+                                ByteSubarray bases = block.getBases();
+                                if(bases != null) {
+                                    for (int pos = adjustedStart; pos < adjustedEnd; pos++) {
+                                        byte base = 0;
+                                        int baseIdx = pos - blockStart;
+                                        if (bases != null && baseIdx >= 0 && baseIdx < bases.length) {
+                                            base = bases.getByte(baseIdx);
+                                        }
+                                        //int idx = pos - blockStart;
+                                        //byte quality = (idx >= 0 && idx < block.qualities.length) ?
+                                        //block.qualities[pos - blockStart] : (byte) 0;
+                                        counter.incrementCount(pos, base, strand);
                                     }
-                                    //int idx = pos - blockStart;
-                                    //byte quality = (idx >= 0 && idx < block.qualities.length) ?
-                                    //block.qualities[pos - blockStart] : (byte) 0;
-                                    counter.incrementCount(pos, base, strand);
                                 }
                             }
                         }
