@@ -806,7 +806,7 @@ public abstract class AbstractTrack implements Track {
             double centerValue = (getTrackType() == TrackType.ALLELE_SPECIFIC_COPY_NUMBER)
                     ? 1.0 : 2.0;
 
-            return (float) (Math.log(Math.max(Float.MIN_VALUE, dataY) / centerValue) / Globals.log2);
+            return (float) (Globals.log2(Math.max(Float.MIN_VALUE, dataY) / centerValue));
         } else {
             return dataY;
         }
@@ -950,6 +950,22 @@ public abstract class AbstractTrack implements Track {
     // End of Roche-Tessella modification
 
 
+    public void setShowFeatureNames(boolean b) {
+        this.showFeatureNames = b;
+    }
+
+    @Override
+    public boolean isShowFeatureNames() {
+        return showFeatureNames;
+    }
+
+    /**
+     * Restore track from XML serialization -- work in progress
+     * //        <renderer="BASIC_FEATURE" sortable="false" visible="true" windowFunction="count">
+     *
+     * @param element
+     */
+
     @Override
     public void marshalXML(Document document, Element element) {
 
@@ -1009,22 +1025,6 @@ public abstract class AbstractTrack implements Track {
     }
 
 
-    public void setShowFeatureNames(boolean b) {
-        this.showFeatureNames = b;
-    }
-
-    @Override
-    public boolean isShowFeatureNames() {
-        return showFeatureNames;
-    }
-
-    /**
-     * Restore track from XML serialization -- work in progress
-     * //        <renderer="BASIC_FEATURE" sortable="false" visible="true" windowFunction="count">
-     *
-     * @param element
-     */
-
     @Override
     public void unmarshalXML(Element element, Integer version) {
 
