@@ -298,7 +298,7 @@ public class FeatureTrack extends AbstractTrack implements IGVEventObserver {
      */
     public int getNumberOfFeatureLevels() {
         if (packedFeaturesMap.size() > 0) {
-            int n = 0;
+            int n = 1;
             for (PackedFeatures pf : packedFeaturesMap.values()) {
                 //dhmay adding null check.  To my mind this shouldn't be necessary, but we're encountering
                 //it intermittently.  Food for future thought
@@ -439,14 +439,23 @@ public class FeatureTrack extends AbstractTrack implements IGVEventObserver {
     }
 
 
+    /**
+     * Return an info URL for a specific feature, constructed as follows
+     *
+     * @param igvFeature
+     * @return
+     */
     private String getFeatureURL(IGVFeature igvFeature) {
-        String url = igvFeature.getURL();
+        String url = igvFeature.getURL();    // Explicity URL setting
         if (url == null) {
-            String trackURL = getFeatureInfoURL();
-            if (trackURL != null && igvFeature.getName() != null) {
-                String name = labelField != null ? igvFeature.getDisplayName(labelField) : igvFeature.getName();
-                String encodedID = StringUtils.encodeURL(name);
-                url = trackURL.replaceAll("\\$\\$", encodedID);
+            String trackURL = getFeatureInfoURL();   // Template
+            if (trackURL != null) {
+                String idOrName = igvFeature.getIdentifier() != null ?
+                        igvFeature.getIdentifier() :
+                        labelField != null ?
+                                igvFeature.getDisplayName(labelField) :
+                                igvFeature.getName();
+                    url = trackURL.replaceAll("\\$\\$", StringUtils.encodeURL(idOrName));
             }
         }
         return url;
@@ -472,7 +481,7 @@ public class FeatureTrack extends AbstractTrack implements IGVEventObserver {
             Iterator<Feature> iter = source.getFeatures(chr, start, end);
             while (iter.hasNext()) {
                 Feature f = iter.next();
-                if(f.getEnd() >= start && f.getStart() <= end) {
+                if (f.getEnd() >= start && f.getStart() <= end) {
                     features.add(f);
                 }
             }
@@ -624,7 +633,7 @@ public class FeatureTrack extends AbstractTrack implements IGVEventObserver {
         MouseEvent e = te.getMouseEvent();
         final ReferenceFrame referenceFrame = te.getFrame();
         if (referenceFrame != null) {
-            double location = referenceFrame.getChromosomePosition(e.getX());
+            double location = referenceFrame.getChromosomePosition(e);
             List<Feature> features = getAllFeatureAt(location, e.getY(), referenceFrame);
             return (features != null && features.size() > 0) ? features.get(0) : null;
         } else {
