@@ -88,18 +88,24 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
             }
         }
 
-        // Set the group autoscale attribute only of all tracks are in the same group
-        this.removeAttribute(AttributeManager.GROUP_AUTOSCALE);
-        if (memberTracks.size() > 0) {
+        // Set the group autoscale attribute only IF all tracks are in the same group
+        if (memberTracks != null && memberTracks.size() > 1) {
             String group = memberTracks.iterator().next().getAttributeValue(AttributeManager.GROUP_AUTOSCALE);
             if (group != null) {
                 for (Track t : memberTracks) {
-                    if (!group.equals(t.getAttributeValue(AttributeManager.GROUP_AUTOSCALE))) return;
+                    if (!group.equals(t.getAttributeValue(AttributeManager.GROUP_AUTOSCALE))) {
+                        this.removeAttribute(AttributeManager.GROUP_AUTOSCALE);
+                        group = null;
+                        break;
+                    }
+                }
+                if (group != null) {
+                    this.setAttributeValue(AttributeManager.GROUP_AUTOSCALE, group);
                 }
-                this.setAttributeValue(AttributeManager.GROUP_AUTOSCALE, group);
             }
         }
 
+
         setTrackAlphas(alpha);
     }
 
@@ -108,10 +114,8 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
         return this.memberTracks.stream().allMatch((t) -> t.isReadyToPaint(frame));
     }
 
-
     @Override
     public synchronized void load(ReferenceFrame referenceFrame) {
-
         for (DataTrack t : memberTracks) {
             if (!t.isReadyToPaint(referenceFrame)) {
                 t.load(referenceFrame);
@@ -150,8 +154,6 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
 
     @Override
     public void render(RenderContext context, Rectangle rect) {
-
-        context.setMerged(true);
         for (Track track : memberTracks) {
             track.render(context, rect);
         }
@@ -209,15 +211,7 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
     public LoadedDataInterval<List<LocusScore>> getSummaryScores(String chr, int startLocation, int endLocation, int zoom) {
         return null;
     }
-
-    @Override
-    public void setRendererClass(Class rc) {
-        super.setRendererClass(rc);
-        for (Track track : memberTracks) {
-            track.setRendererClass(rc);
-        }
-    }
-
+    
     @Override
     public boolean getAutoScale() {
         boolean autoScale = true;
@@ -237,7 +231,7 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
     @Override
     public void setAttributeValue(String name, String value) {
         super.setAttributeValue(name, value);
-        if (name.equals(AttributeManager.GROUP_AUTOSCALE)) {
+        if (name.equals(AttributeManager.GROUP_AUTOSCALE) && memberTracks != null) {
             for (Track track : memberTracks) {
                 track.setAttributeValue(name, value);
             }
@@ -254,6 +248,28 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
         }
     }
 
+    @Override
+    public String getAttributeValue(String attributeName) {
+        if (super.getAttributeValue(attributeName) != null) {
+            return super.getAttributeValue(attributeName);
+        } else if (memberTracks.size() > 0) {
+            String value = null;
+            for (Track track : memberTracks) {
+                String nm = track.getAttributeValue(attributeName);
+                if (nm != null) {
+                    if (value == null) {
+                        value = nm;
+                    } else if (!value.equals(nm)) {
+                        value += " / " + nm;
+                    }
+                }
+            }
+            return value;
+        } else {
+            // Should be impossible
+            return null;
+        }
+    }
 
     @Override
     public ContinuousColorScale getColorScale() {
@@ -353,6 +369,7 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
         }
     }
 
+    @Override
     public void marshalXML(Document document, Element element) {
 
         super.marshalXML(document, element);
@@ -360,28 +377,23 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
         if (alpha != DEFAULT_ALPHA) {
             element.setAttribute("alpha", String.valueOf(alpha));
         }
-
         for (DataTrack track : memberTracks) {
             Element trackElement = document.createElement(SessionElement.TRACK);
             track.marshalXML(document, trackElement);
             element.appendChild(trackElement);
         }
-
     }
 
     @Override
     public void unmarshalXML(Element element, Integer version) {
 
         super.unmarshalXML(element, version);
-
         if (element.hasAttribute("alpha")) {
             this.alpha = Double.valueOf(element.getAttribute("alpha"));
         }
         // Un-marshalling handled in IGVSessionReader
-
     }
 
-
     private enum ChangeTrackMethod {
         POSITIVE, NEGATIVE
     }
@@ -473,7 +485,7 @@ public class MergedTracks extends DataTrack implements ScalableTrack {
         optionPane.setMessage(new Object[]{"Adjust transparency: ", slider});
         optionPane.setMessageType(JOptionPane.QUESTION_MESSAGE);
         optionPane.setOptionType(JOptionPane.OK_CANCEL_OPTION);
-        JDialog dialog = optionPane.createDialog(IGV.getMainFrame(), "Transparency");
+        JDialog dialog = optionPane.createDialog(IGV.getInstance().getMainFrame(), "Transparency");
         return dialog;
     }
 
