@@ -42,6 +42,8 @@ import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.ResourceLocator;
 import org.broad.igv.util.RuntimeUtils;
 import org.broad.igv.util.collections.CollUtils;
+import org.broad.igv.variant.Variant;
+import org.broad.igv.variant.vcf.MateVariant;
 
 import java.io.File;
 import java.io.IOException;
@@ -54,6 +56,7 @@ import java.util.*;
 abstract public class TribbleFeatureSource implements org.broad.igv.track.FeatureSource {
 
     IGVFeatureReader reader;
+    FeatureReader wrappedReader;
     boolean isVCF;
     Genome genome;
 
@@ -61,7 +64,7 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
      * Map of IGV chromosome name -> source name
      */
     Map<String, String> chrNameMap = new HashMap<String, String>();
-    private int featureWindowSize;
+    private Integer featureWindowSize;
     Object header;
     Class featureClass;
 
@@ -69,60 +72,79 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
         return getFeatureSource(locator, genome, true);
     }
 
-    public static TribbleFeatureSource getFeatureSource(ResourceLocator locator, Genome genome, boolean useCache) throws IOException, TribbleIndexNotFoundException {
+    public static TribbleFeatureSource getFeatureSource(ResourceLocator locator, Genome genome, boolean useCache) throws IOException {
 
         AbstractFeatureReader.setComponentMethods(IGVComponentMethods.getInstance());
 
         FeatureCodec codec = CodecFactory.getCodec(locator, genome);
 
         boolean indexExists = false;
+        String idxPath = null;
+        boolean indexRequired = false;
         // Explicit index path
-        String idxPath = locator.getIndexPath();
-        if (idxPath != null) {
-            if (FileUtils.isRemote(idxPath)) {
-                idxPath = HttpUtils.mapURL(idxPath);
-            }
-            indexExists = true;
-        } else {
-            String maybeIdxPath = ResourceLocator.indexFile(locator);
-            if (maybeIdxPath == null) {
-                indexExists = false;
+        if (!locator.isDataURL()) {
+            idxPath = locator.getIndexPath();
+            if (idxPath != null && idxPath.length() > 0) {
+                if (FileUtils.isRemote(idxPath)) {
+                    idxPath = HttpUtils.mapURL(idxPath);
+                }
+                indexExists = true;
             } else {
-                if (FileUtils.isRemote(maybeIdxPath)) {
-                    maybeIdxPath = HttpUtils.mapURL(maybeIdxPath);
-                }
-                if(FileUtils.resourceExists(maybeIdxPath)) {
-                    indexExists = true;
-                    idxPath = maybeIdxPath;
+                String maybeIdxPath = ResourceLocator.indexFile(locator);
+                if (maybeIdxPath == null || maybeIdxPath.length() == 0) {
+                    indexExists = false;
+                } else {
+                    if (FileUtils.isRemote(maybeIdxPath)) {
+                        maybeIdxPath = HttpUtils.mapURL(maybeIdxPath);
+                    }
+                    if (FileUtils.resourceExists(maybeIdxPath)) {
+                        indexExists = true;
+                        idxPath = maybeIdxPath;
+                    }
                 }
             }
-        }
 
-
-        // Optionally let the user create an index.
-        final int hundredMB = 100000000;
-        final int oneGB = 1000000000;
-        long size = FileUtils.getLength(locator.getPath());
-        final boolean indexRequired = size > oneGB;
-        if (!Globals.isHeadless() && locator.isLocal() && !locator.getPath().endsWith(".gz") && !indexExists) {
-            if (size > hundredMB) {
-                createIndex(locator, indexRequired);   // Note, might return null.
+            // Optionally let the user create an index.
+            if (!FileUtils.isRemote(locator.getPath())) {
+                final int hundredMB = 100000000;
+                final int oneGB = 1000000000;
+                long size = FileUtils.getLength(locator.getPath());
+                indexRequired = size > 10 * oneGB;
+                if (!Globals.isHeadless() && locator.isLocal() && !locator.getPath().endsWith(".gz") && !indexExists) {
+                    if (size > hundredMB) {
+                        createIndex(locator, indexRequired);   // Note, might return null.
+                    }
+                }
             }
         }
 
         String path = locator.getPath();
         if (FileUtils.isRemote(path)) {
-            path = HttpUtils.mapURL(path);
+            path = HttpUtils.createURL(path).toExternalForm();
+        }
+        if (idxPath != null && idxPath.length() > 0 && FileUtils.isRemote(idxPath)) {
+            idxPath = HttpUtils.createURL(idxPath).toExternalForm();
         }
         AbstractFeatureReader basicReader = AbstractFeatureReader.getFeatureReader(path, idxPath, codec, indexRequired || indexExists);
 
+
         if (indexExists) { //basicReader.hasIndex()) {
-            return new IndexedFeatureSource(basicReader, codec, locator, genome, true);
+            return new IndexedFeatureSource(basicReader, codec, locator, genome, useCache, true);
         } else {
             return new NonIndexedFeatureSource(basicReader, codec, locator, genome);
         }
     }
 
+    public static AbstractFeatureReader getBasicReader(ResourceLocator locator, Genome genome) throws IOException {
+        AbstractFeatureReader.setComponentMethods(IGVComponentMethods.getInstance());
+        FeatureCodec codec = CodecFactory.getCodec(locator, genome);
+
+        String path = locator.getPath();
+        if (FileUtils.isRemote(path)) {
+            path = HttpUtils.mapURL(path);
+        }
+        return AbstractFeatureReader.getFeatureReader(path, null, codec, false);
+    }
 
     /**
      * Present a dialog for the user to create an index.  This method can return null if the user cancels, or there
@@ -139,21 +161,19 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
                 "be located. An index is " + (indexRequired ? "required" : "recommended") +
                 " to view files of this size.   Click \"Go\" to create one now or \"Cancel" +
                 " to proceed without an index.";
-        IndexCreatorDialog dialog = IndexCreatorDialog.createShowDialog(IGV.getMainFrame(), baseFile, newIdxFile, messageText);
+        IndexCreatorDialog dialog = IndexCreatorDialog.createShowDialog(IGV.getInstance().getMainFrame(), baseFile, newIdxFile, messageText);
         return (Index) dialog.getIndex();
     }
 
 
-    private TribbleFeatureSource(ResourceLocator locator, AbstractFeatureReader reader, FeatureCodec codec, Genome genome, boolean useCache) throws IOException {
+    private TribbleFeatureSource(AbstractFeatureReader reader, FeatureCodec codec, Genome genome) throws IOException {
 
         this.genome = genome;
         this.isVCF = codec.getClass() == VCFWrapperCodec.class;
         this.featureClass = codec.getFeatureType();
         this.header = reader.getHeader();
-        this.featureWindowSize = estimateFeatureWindowSize(reader);
-        this.reader = useCache ?
-                new CachingFeatureReader(reader, 5, featureWindowSize) :
-                new TribbleReaderWrapper(reader);
+        this.reader = new TribbleReaderWrapper(reader);
+        this.wrappedReader = reader;
     }
 
     protected abstract int estimateFeatureWindowSize(FeatureReader reader);
@@ -167,14 +187,10 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
     }
 
     public int getFeatureWindowSize() {
-        return featureWindowSize;
-    }
-
-    public void setFeatureWindowSize(int size) {
-        this.featureWindowSize = size;
-        if (reader instanceof CachingFeatureReader) {
-            ((CachingFeatureReader) reader).setBinSize(size);
+        if (featureWindowSize == null) {
+            this.featureWindowSize = estimateFeatureWindowSize(this.wrappedReader);
         }
+        return featureWindowSize;
     }
 
     public Object getHeader() {
@@ -185,9 +201,8 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
 
 
         private IndexedFeatureSource(AbstractFeatureReader basicReader, FeatureCodec codec, ResourceLocator locator,
-                                     Genome genome, boolean useCache) throws IOException {
-            super(locator, basicReader, codec, genome, useCache);
-
+                                     Genome genome, boolean useCache, boolean useIndex) throws IOException {
+            super(basicReader, codec, genome);
 
             if (genome != null) {
                 Collection<String> seqNames = reader.getSequenceNames();
@@ -303,7 +318,7 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
     }
 
 
-    static class NonIndexedFeatureSource extends TribbleFeatureSource {
+    public static class NonIndexedFeatureSource extends TribbleFeatureSource {
 
         /**
          * Map containing all features.  Used only when there is no index.
@@ -314,9 +329,9 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
 
         private NonIndexedFeatureSource(AbstractFeatureReader basicReader, FeatureCodec codec, ResourceLocator locator, Genome genome) throws IOException {
 
-            super(locator, basicReader, codec, genome, false);
+            super(basicReader, codec, genome);
 
-            featureMap = new HashMap<String, List<Feature>>(25);
+            featureMap = new HashMap<>(25);
             Iterator<Feature> iter = null;
 
             try {
@@ -335,6 +350,22 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
                     }
                     featureList.add(f);
                     if (f instanceof NamedFeature) FeatureDB.addFeature((NamedFeature) f, genome);
+
+                    if (this.isVCF && f instanceof Variant) {
+                        Variant v = (Variant) f;
+                        String chr2 = v.getAttributeAsString("CHR2");
+                        String pos2 = v.getAttributeAsString("END");
+                        if (chr2 != null && pos2 != null) {
+                            String mateChr = genome == null ? chr2 : genome.getCanonicalChrName(chr2);
+                            MateVariant mate = new MateVariant(mateChr, Integer.parseInt(pos2), v);
+                            featureList = featureMap.get(mateChr);
+                            if (featureList == null) {
+                                featureList = new ArrayList();
+                                featureMap.put(mateChr, featureList);
+                            }
+                            featureList.add(mate);
+                        }
+                    }
                 }
             } finally {
                 if (iter instanceof CloseableTribbleIterator) {
@@ -353,16 +384,6 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
             }
         }
 
-        @Override
-        public void dispose() {
-            super.dispose();
-            for (List<Feature> featureList : featureMap.values()) {
-                for (Feature f : featureList) {
-                    if (f instanceof NamedFeature) FeatureDB.removeFeature((NamedFeature) f, genome);
-                }
-            }
-        }
-
         @Override
         public boolean isIndexed() {
             return false;
@@ -390,6 +411,15 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
 
         }
 
+        public List<Feature> getAllFeatures() throws IOException {
+            List<Feature> allFeatures = new ArrayList<>();
+            for (List<Feature> chrFeatures : featureMap.values()) {
+                allFeatures.addAll(chrFeatures);
+            }
+            return allFeatures;
+        }
+
+
         @Override
         protected Collection<String> getSequenceNames() {
             return featureMap.keySet();
@@ -397,7 +427,7 @@ abstract public class TribbleFeatureSource implements org.broad.igv.track.Featur
 
         @Override
         protected int estimateFeatureWindowSize(FeatureReader reader) {
-            return 0;
+            return -1;
         }
 
         protected void sampleGenomeFeatures() {
