@@ -48,16 +48,15 @@ import org.broad.igv.feature.Range;
 import org.broad.igv.feature.RegionOfInterest;
 import org.broad.igv.feature.Strand;
 import org.broad.igv.feature.genome.*;
-import org.broad.igv.jbrowse.CircularViewUtilities;
 import org.broad.igv.lists.GeneList;
 import org.broad.igv.logging.LogManager;
 import org.broad.igv.logging.Logger;
-import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.IGVPreferences;
 import org.broad.igv.prefs.PreferencesEditor;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.sam.AlignmentTrack;
 import org.broad.igv.sam.InsertionSelectionEvent;
+import org.broad.igv.sam.SortOption;
 import org.broad.igv.session.*;
 import org.broad.igv.track.*;
 import org.broad.igv.ui.WaitCursorManager.CursorToken;
@@ -1378,21 +1377,16 @@ public class IGV implements IGVEventObserver {
     }
 
 
-    public void sortAlignmentTracks(AlignmentTrack.SortOption option, String tag) {
-        sortAlignmentTracks(option, null, tag);
+    public void sortAlignmentTracks(SortOption option, String tag, final boolean invertSort) {
+        sortAlignmentTracks(option, null, tag, invertSort);
     }
 
-    public void sortAlignmentTracks(AlignmentTrack.SortOption option, Double location, String tag) {
-        double actloc;
-        List<Track> alignmentTracks = getAllTracks().stream()
+    public void sortAlignmentTracks(SortOption option, Double location, String tag, boolean invertSort) {
+        List<AlignmentTrack> alignmentTracks = getAllTracks().stream()
                 .filter(track -> track instanceof AlignmentTrack)
+                .map(track -> (AlignmentTrack)track)
+                .peek(track -> track.sortRows(option, location, tag, invertSort))
                 .collect(Collectors.toList());
-        for (Track t : alignmentTracks) {
-            for (ReferenceFrame frame : FrameManager.getFrames()) {
-                actloc = location != null ? location : frame.getCenter();
-                ((AlignmentTrack) t).sortRows(option, frame, actloc, tag);
-            }
-        }
         this.repaint(alignmentTracks);
     }
 
@@ -1545,15 +1539,15 @@ public class IGV implements IGVEventObserver {
     }
 
     public List<FeatureTrack> getFeatureTracks() {
-        Iterable<FeatureTrack> featureTracksIter = Iterables.filter(getAllTracks(), FeatureTrack.class);
-        List<FeatureTrack> featureTracks = Lists.newArrayList(featureTracksIter);
-        return featureTracks;
+        return Lists.newArrayList(Iterables.filter(getAllTracks(), FeatureTrack.class));
     }
 
     public List<DataTrack> getDataTracks() {
-        Iterable<DataTrack> dataTracksIter = Iterables.filter(getAllTracks(), DataTrack.class);
-        List<DataTrack> dataTracks = Lists.newArrayList(dataTracksIter);
-        return dataTracks;
+        return Lists.newArrayList(Iterables.filter(getAllTracks(), DataTrack.class));
+    }
+
+    public List<AlignmentTrack> getAlignmentTracks() {
+        return Lists.newArrayList(Iterables.filter(getAllTracks(), AlignmentTrack.class));
     }
 
     public void clearSelections() {
