@@ -36,9 +36,9 @@ import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.event.IGVEventObserver;
 import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.feature.genome.GenomeUtils;
-import org.broad.igv.google.GoogleUtils;
-import org.broad.igv.google.OAuthProvider;
-import org.broad.igv.google.OAuthUtils;
+import org.broad.igv.util.GoogleUtils;
+import org.broad.igv.oauth.OAuthProvider;
+import org.broad.igv.oauth.OAuthUtils;
 import org.broad.igv.lists.GeneListManagerUI;
 import org.broad.igv.logging.LogManager;
 import org.broad.igv.logging.Logger;
@@ -57,7 +57,6 @@ import org.broad.igv.ui.panel.ReorderPanelsDialog;
 import org.broad.igv.ui.util.*;
 import org.broad.igv.util.AmazonUtils;
 import org.broad.igv.util.BrowserLauncher;
-import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.LongRunningTask;
 import org.broad.igv.util.blat.BlatClient;
 import org.broad.igv.util.encode.EncodeFileBrowser;
@@ -74,8 +73,6 @@ import java.io.File;
 import java.io.IOException;
 import java.net.URI;
 import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.HashSet;
 import java.util.List;
 
 import static org.broad.igv.prefs.Constants.*;
@@ -626,7 +623,8 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         menuAction =
                 new MenuAction("Select Attributes to Show...", null, KeyEvent.VK_S) {
                     @Override
-                    public void actionPerformed(ActionEvent e) {igv.doSelectDisplayableAttribute();
+                    public void actionPerformed(ActionEvent e) {
+                        igv.doSelectDisplayableAttribute();
                     }
                 };
         menuAction.setToolTipText(SELECT_DISPLAYABLE_ATTRIBUTES_TOOLTIP);
@@ -910,7 +908,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         JMenuItem updateCS = new JMenuItem("Update chrom sizes");
         updateCS.addActionListener(e -> {
             try {
-                GenomeUtils.main(new String [] {});
+                GenomeUtils.main(new String[]{});
             } catch (IOException ioException) {
                 ioException.printStackTrace();
             }
@@ -931,7 +929,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         final JMenuItem login = new JMenuItem("Login");
         login.addActionListener(e -> {
             try {
-                OAuthProvider oauth = OAuthUtils.getInstance().getProvider("Amazon");
+                OAuthProvider oauth = OAuthUtils.getInstance().getAWSProvider();
                 oauth.openAuthorizationPage();
             } catch (Exception ex) {
                 MessageUtils.showErrorMessage("Error fetching oAuth tokens.  See log for details", ex);
@@ -945,7 +943,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         // Logout
         final JMenuItem logout = new JMenuItem("Logout");
         logout.addActionListener(e -> {
-            OAuthProvider oauth = OAuthUtils.getInstance().getProvider("Amazon");
+            OAuthProvider oauth = OAuthUtils.getInstance().getAWSProvider();
             oauth.logout();
         });
         logout.setEnabled(false);
@@ -973,9 +971,8 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
             public void menuSelected(MenuEvent e) {
                 if (AmazonUtils.GetCognitoConfig() != null) {
                     Runnable runnable = () -> {
-                        OAuthProvider oauth = OAuthUtils.getInstance().getProvider("Amazon");
-                        boolean loggedIn = false;
-                        loggedIn = oauth.isLoggedIn();
+                        OAuthProvider oauth = OAuthUtils.getInstance().getAWSProvider();
+                        boolean loggedIn = oauth.isLoggedIn();
                         log.debug("MenuBar is user loggedIn?: " + loggedIn);
 
                         if (loggedIn) {
@@ -1009,11 +1006,13 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
     private JMenu createGoogleMenu() throws IOException {
 
         // Dynamically name menu - dwm08
-        final OAuthProvider oauth = OAuthUtils.getInstance().getProvider();
+        final OAuthProvider oauth = OAuthUtils.getInstance().getDefaultProvider();
 
-        if (oauth != null) {  // TODO -- how do we know this is a google provider?
-            oauth.setAuthProvider("Google");
-            JMenu menu = new JMenu(oauth.getAuthProvider());
+        if (oauth != null) {
+
+            JMenu menu = new JMenu("Google");
+
+            boolean isLoggedIn = oauth.isLoggedIn();
 
             final JMenuItem login = new JMenuItem("Login ... ");
             login.addActionListener(e -> {
@@ -1025,7 +1024,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
                 }
 
             });
-            //login.setEnabled(false);
+            login.setEnabled(!isLoggedIn);
             menu.add(login);
 
 
@@ -1034,7 +1033,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
                 oauth.logout();
                 GoogleUtils.setProjectID(null);
             });
-            logout.setEnabled(false);
+            logout.setEnabled(isLoggedIn);
             menu.add(logout);
 
             final JMenuItem projectID = new JMenuItem("Enter Project ID ...");
@@ -1044,19 +1043,15 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
             menu.addMenuListener(new MenuListener() {
                 @Override
                 public void menuSelected(MenuEvent e) {
-                    Runnable runnable = () -> {
-                        boolean loggedIn = OAuthUtils.getInstance().getProvider().isLoggedIn();
-
-                        if (loggedIn) {
-                            login.setText(oauth.getCurrentUserName());
-                        } else {
-                            login.setText("Login ...");
-                        }
-                        login.setEnabled(!loggedIn);
-                        logout.setEnabled(loggedIn);
-                    };
-
-                    LongRunningTask.submit(runnable);
+                    OAuthProvider oAuthProvider = OAuthUtils.getInstance().getDefaultProvider();
+                    boolean loggedIn = oAuthProvider.isLoggedIn();
+                    if (loggedIn && oAuthProvider.getCurrentUserName() != null) {
+                        login.setText(oAuthProvider.getCurrentUserName());
+                    } else {
+                        login.setText("Login ...");
+                    }
+                    login.setEnabled(!loggedIn);
+                    logout.setEnabled(loggedIn);
                 }
 
                 @Override
@@ -1119,6 +1114,10 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
         return false;
     }
 
+    public JMenu getViewMenu() {
+        return viewMenu;
+    }
+
     final public void doExitApplication() {
 
         try {
@@ -1168,7 +1167,7 @@ public class IGVMenuBar extends JMenuBar implements IGVEventObserver {
 
             String blatSequence = MessageUtils.showInputDialog("Enter sequence to blat:");
             if (blatSequence != null) {
-                if(blatSequence.length() < 20 || blatSequence.length() > 8000) {
+                if (blatSequence.length() < 20 || blatSequence.length() > 8000) {
                     MessageUtils.showMessage("BLAT sequences must be between 20 and 8000 bases in length.");
                 } else {
                     BlatClient.doBlatQuery(blatSequence, "BLAT");
