@@ -31,11 +31,9 @@ import htsjdk.samtools.seekablestream.SeekableStreamFactory;
 import org.broad.igv.logging.*;
 import org.broad.igv.DirectoryManager;
 import org.broad.igv.Globals;
-import org.broad.igv.batch.CommandListener;
-import org.broad.igv.google.OAuthUtils;
+import org.broad.igv.oauth.OAuthUtils;
 import org.broad.igv.prefs.IGVPreferences;
 import org.broad.igv.prefs.PreferencesManager;
-import org.broad.igv.ui.util.UIUtilities;
 import org.broad.igv.util.FileUtils;
 import org.broad.igv.util.HttpUtils;
 import org.broad.igv.util.RuntimeUtils;
@@ -49,12 +47,10 @@ import java.awt.event.WindowEvent;
 import java.io.File;
 import java.io.FileWriter;
 import java.io.UnsupportedEncodingException;
-import java.net.URL;
 import java.net.URLDecoder;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
-import java.util.HashSet;
 
 import static org.broad.igv.prefs.Constants.*;
 
@@ -97,15 +93,10 @@ public class Main {
         }
         checkDotIgvDirectory();
 
+        HttpUtils.getInstance().updateProxySettings();
+
         htsjdk.tribble.util.ParsingUtils.setURLHelperFactory(IGVUrlHelperFactory.getInstance());
 
-        try {
-            OAuthUtils.getInstance();  // Initialize oauth
-        } catch (Exception e) {
-            log.error("Warning: Error fetching oAuth properties: " + e.getMessage());
-        }
-
-
         Runnable runnable = () -> {
             if (Globals.IS_WINDOWS && System.getProperty("os.name").contains("10")) {
                 UIManager.put("FileChooser.useSystemExtensionHiding", false);
@@ -295,8 +286,6 @@ public class Main {
             PreferencesManager.getPreferences().overrideGenomeServerURL(igvArgs.getGenomeServerURL());
         }
 
-        HttpUtils.getInstance().updateProxySettings();
-
         SeekableStreamFactory.setInstance(IGVSeekableStreamFactory.getInstance());
 
         // Start IGV's UI itself (frame) and other components
