@@ -1,6 +1,7 @@
 package org.broad.igv.ui.commandbar;
 
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
+import org.broad.igv.DirectoryManager;
 import org.broad.igv.event.GenomeResetEvent;
 import org.broad.igv.event.IGVEventBus;
 import org.broad.igv.feature.genome.GenomeListItem;
@@ -8,7 +9,9 @@ import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.feature.genome.GenomeServerException;
 import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.UIConstants;
-import org.broad.igv.ui.util.*;
+import org.broad.igv.ui.util.MessageUtils;
+import org.broad.igv.ui.util.ProgressBar;
+import org.broad.igv.ui.util.UIUtilities;
 import org.broad.igv.util.LongRunningTask;
 
 import javax.swing.*;
@@ -16,15 +19,17 @@ import javax.swing.border.EmptyBorder;
 import java.awt.*;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
+import java.io.File;
 import java.io.IOException;
 import java.util.*;
+import java.util.List;
 
 /**
  * Created by jrobinso on 7/6/17.
  */
 public class GenomeComboBox extends JComboBox<GenomeListItem> {
 
-    private static Logger log = Logger.getLogger(GenomeComboBox.class);
+    private static Logger log = LogManager.getLogger(GenomeComboBox.class);
 
     public GenomeComboBox() {
 
@@ -37,7 +42,19 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
         setModel(getModelForGenomeListComboBox());
         String curId = GenomeManager.getInstance().getGenomeId();
         Object item = GenomeListManager.getInstance().getLoadedGenomeListItemById(curId);
-        if (item != null) setSelectedItem(item);
+        if (item != null) {
+            setSelectedItem(item);
+        }
+    }
+
+    public boolean hasItem(Object item) {
+        int c = this.getItemCount();
+        for (int i = 0; i < c; i++) {
+            if (item.equals(this.getItemAt(i))) {
+                return true;
+            }
+        }
+        return false;
     }
 
     /**
@@ -56,8 +73,8 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
         }
 
         Vector<GenomeListItem> vector = new Vector<>(genomes);
-        vector.sort((o1, o2) -> o1.getDisplayableName().compareTo(o2.getDisplayableName()));
-        vector.add(GenomeListItem.ITEM_MORE);
+        vector.sort(Comparator.comparing(GenomeListItem::getDisplayableName));
+        vector.add(GenomeListItem.DOWNLOAD_ITEM);
         return new DefaultComboBoxModel(vector);
     }
 
@@ -65,7 +82,6 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
     class GenomeBoxActionListener implements ActionListener {
 
         public void actionPerformed(ActionEvent actionEvent) {
-
             Object selItem = getSelectedItem();
             if (!(selItem instanceof GenomeListItem)) {
                 return;
@@ -76,13 +92,10 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
 
         private void loadGenomeListItem(final GenomeListItem genomeListItem) {
 
-            log.info("Enter genome combo box");
-
             // If we haven't changed genomes do nothing
             if (genomeListItem.getId().equalsIgnoreCase(GenomeManager.getInstance().getGenomeId())) {
                 return;
             }
-            log.info("Loading " + genomeListItem.getDisplayableName());
 
             final Runnable runnable = new Runnable() {
 
@@ -93,17 +106,17 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
 
                     if (genomeListItem != null && genomeListItem.getPath() != null) {
 
-                        log.info("Loading " + genomeListItem.getId());
+                        //log.warn("Loading " + genomeListItem.getId());
 
                         //User selected "more", pull up dialog and revert combo box
-                        if (genomeListItem == GenomeListItem.ITEM_MORE) {
+                        if (genomeListItem == GenomeListItem.DOWNLOAD_ITEM) {
                             loadGenomeFromServer();
                             return;
                         }
 
                         UIUtilities.invokeAndWaitOnEventThread(() -> {
                             monitor = new org.broad.igv.ui.util.ProgressMonitor();
-                            progressDialog = ProgressBar.showProgressDialog(IGV.getMainFrame(), "Loading Genome...", monitor, false);
+                            progressDialog = ProgressBar.showProgressDialog(IGV.getInstance().getMainFrame(), "Loading Genome...", monitor, false);
                         });
 
                         try {
@@ -111,12 +124,12 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
                         } catch (GenomeServerException e) {
                             log.error("Error loading genome: " + genomeListItem.getId() + "  " + genomeListItem.getPath(), e);
                             JOptionPane.showMessageDialog(
-                                    IGV.getMainFrame(),
+                                    IGV.getInstance().getMainFrame(),
                                     "Error loading genome: " + genomeListItem.getDisplayableName());
                         } catch (Exception e) {
                             log.error(e);
                             int choice = JOptionPane.showConfirmDialog(
-                                    IGV.getMainFrame(), "The genome [" + genomeListItem.getId() +
+                                    IGV.getInstance().getMainFrame(), "The genome [" + genomeListItem.getId() +
                                             "] could not be read. Would you like to remove the selected entry?",
                                     "", JOptionPane.OK_CANCEL_OPTION);
 
@@ -223,37 +236,41 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
                 //Could not reach genome server.  Not necessary to display a message, getServerGenomeArchiveList does it already
                 return;
             }
-
-            GenomeSelectionDialog dialog = new GenomeSelectionDialog(IGV.getMainFrame(), inputListItems);
-
+            GenomeSelectionDialog dialog = new GenomeSelectionDialog(IGV.getInstance().getMainFrame(), inputListItems);
             UIUtilities.invokeAndWaitOnEventThread(() -> dialog.setVisible(true));
 
             if (dialog.isCanceled()) {
                 // Clear the "More..."  selection in pulldown
                 IGVEventBus.getInstance().post(new GenomeResetEvent());
             } else {
+                List<GenomeListItem> selectedValueList = dialog.getSelectedValues();
+                GenomeListItem firstItem = null;
+                for (GenomeListItem selectedValue : selectedValueList) {
+                    if (selectedValue != null) {
+                        boolean success = GenomeManager.getInstance().downloadGenome(selectedValue, dialog.downloadSequence());
+                        if (success) {
+                            GenomeListManager.getInstance().addServerGenomeItem(selectedValue);
+                            firstItem = selectedValue;
+                        }
+                    }
+                }
+                if (firstItem != null) {
+                    try {
 
-                GenomeListItem selectedValue = dialog.getSelectedValue();
+                        GenomeManager.getInstance().loadGenome(firstItem.getPath(), null);
+                        // If the user has previously defined this genome, remove it.
+                        GenomeListManager.getInstance().removeUserDefinedGenome(firstItem.getId());
 
-
-                if (selectedValue != null) {
-
-                    boolean success = GenomeManager.getInstance().downloadGenomes(selectedValue, dialog.downloadSequence());
-
-                    if (success) {
-                        GenomeListManager.getInstance().addServerGenomeItem(selectedValue);
-
-
-                        final GenomeListItem firstItem = selectedValue;
-                        try {
-                            GenomeManager.getInstance().loadGenome(firstItem.getPath(), null);
-                        } catch (IOException e) {
-
-                            GenomeListManager.getInstance().removeGenomeListItem(firstItem);
-                            MessageUtils.showErrorMessage("Error loading genome " + firstItem.getDisplayableName(), e);
-                            log.error("Error loading genome " + firstItem.getDisplayableName(), e);
+                        // If this is a .json genome, attempt to remove existing .genome files
+                        if(firstItem.getPath().endsWith(".json")) {
+                            removeDotGenomeFile(firstItem.getId());
                         }
 
+
+                    } catch (IOException e) {
+                        GenomeListManager.getInstance().removeGenomeListItem(firstItem);
+                        MessageUtils.showErrorMessage("Error loading genome " + firstItem.getDisplayableName(), e);
+                        log.error("Error loading genome " + firstItem.getDisplayableName(), e);
                     }
                 }
             }
@@ -266,4 +283,17 @@ public class GenomeComboBox extends JComboBox<GenomeListItem> {
         }
     }
 
+    public static void removeDotGenomeFile(String id) {
+        try {
+            File dotGenomeFile = new File(DirectoryManager.getGenomeCacheDirectory(), id + ".genome");
+            if(dotGenomeFile.exists()) {
+                dotGenomeFile.delete();
+            }
+        } catch (Exception e) {
+            // If anything goes wrong, just log it, this cleanup is not essential
+            log.error("Error deleting .genome file", e);
+        }
+    }
+
+
 }
