@@ -33,10 +33,12 @@ package org.broad.igv.ui.commandbar;
 import com.jidesoft.swing.JideBoxLayout;
 import com.jidesoft.swing.JideButton;
 import com.jidesoft.swing.JideToggleButton;
-import org.apache.log4j.Logger;
+import org.broad.igv.logging.*;
 import org.broad.igv.Globals;
 import org.broad.igv.event.*;
-import org.broad.igv.feature.genome.*;
+import org.broad.igv.feature.genome.Genome;
+import org.broad.igv.feature.genome.GenomeListItem;
+import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.prefs.Constants;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.session.History;
@@ -44,11 +46,14 @@ import org.broad.igv.ui.IGV;
 import org.broad.igv.ui.ShowDetailsBehavior;
 import org.broad.igv.ui.UIConstants;
 import org.broad.igv.ui.action.FitDataToWindowMenuAction;
+import org.broad.igv.ui.action.ReloadTracksMenuAction;
 import org.broad.igv.ui.panel.FrameManager;
 import org.broad.igv.ui.panel.IGVPopupMenu;
 import org.broad.igv.ui.panel.ReferenceFrame;
 import org.broad.igv.ui.panel.ZoomSliderPanel;
-import org.broad.igv.ui.util.*;
+import org.broad.igv.ui.util.IconFactory;
+import org.broad.igv.ui.util.MessageUtils;
+import org.broad.igv.ui.util.UIUtilities;
 
 import javax.swing.*;
 import javax.swing.border.LineBorder;
@@ -65,7 +70,7 @@ import java.io.IOException;
  */
 public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserver {
 
-    private static Logger log = Logger.getLogger(IGVCommandBar.class);
+    private static Logger log = LogManager.getLogger(IGVCommandBar.class);
 
     final static String MODIFY_DETAILS_TOOLTIP = "Modify popup text behavior in data panels";
     final static int DEFAULT_CHROMOSOME_DROPDOWN_WIDTH = 120;
@@ -97,14 +102,11 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         // Post creation widget setup.
         refreshGenomeListComboBox();
 
-
         String currentChr = FrameManager.getDefaultFrame().getChrName();
         boolean isWholeGenome = currentChr.equals(Globals.CHR_ALL);
 
         chromosomeComboBox.setSelectedItem(currentChr);
-
         roiToggleButton.setEnabled(!isWholeGenome);
-
         zoomControl.setEnabled(!isWholeGenome);
 
         detailsBehaviorButton.addMouseListener(new MouseAdapter() {
@@ -143,9 +145,9 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
 
     public void setGeneListMode(boolean geneListMode) {
 
-        genomeComboBox.setEnabled(!geneListMode);
 //        locationPanel.setEnabled(!geneListMode);
         chromosomeComboBox.setEnabled(!geneListMode);
+        if(geneListMode) searchTextField.setText("");
 //        searchTextField.setEnabled(!geneListMode);
 //        goButton.setEnabled(!geneListMode);
         zoomControl.setEnabled(!geneListMode);
@@ -162,12 +164,11 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
      */
     public void selectGenome(String genomeId) {
 
-        log.info("Selecting genome " + genomeId);
+        //log.warn("Selecting genome " + genomeId);
 
         GenomeListItem selectedItem = GenomeListManager.getInstance().getGenomeListItem(genomeId);
 
-        if (selectedItem == null) {
-
+        if (selectedItem == null || !genomeComboBox.hasItem(selectedItem)) {
             try {
                 GenomeManager.getInstance().loadGenomeById(genomeId);
             } catch (IOException e) {
@@ -183,25 +184,26 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
 
     public void updateCurrentCoordinates() {
 
-        String p = "";
-
-        ReferenceFrame defaultFrame = FrameManager.getDefaultFrame();
-        final String chrName = defaultFrame.getChrName();
-        if (!Globals.CHR_ALL.equals(chrName) && !FrameManager.isGeneListMode()) {
-            p = defaultFrame.getFormattedLocusString();
-        }
-        final String position = p;
-        final History history = IGV.getInstance().getSession().getHistory();
-
-        UIUtilities.invokeOnEventThread(new Runnable() {
-            public void run() {
-                searchTextField.setText(position);
-                forwardButton.setEnabled(history.canGoForward());
-                backButton.setEnabled(history.canGoBack());
-                roiToggleButton.setEnabled(!Globals.CHR_ALL.equals(chrName));
-                zoomControl.setEnabled(!Globals.CHR_ALL.equals(chrName));
+        if(IGV.hasInstance()) {
+            String p = "";
+            ReferenceFrame defaultFrame = FrameManager.getDefaultFrame();
+            final String chrName = defaultFrame.getChrName();
+            if (!Globals.CHR_ALL.equals(chrName) && !FrameManager.isGeneListMode()) {
+                p = defaultFrame.getFormattedLocusString();
             }
-        });
+            final String position = p;
+            final History history = IGV.getInstance().getSession().getHistory();
+
+            UIUtilities.invokeOnEventThread(new Runnable() {
+                public void run() {
+                    searchTextField.setText(position);
+                    forwardButton.setEnabled(history.canGoForward());
+                    backButton.setEnabled(history.canGoBack());
+                    roiToggleButton.setEnabled(!Globals.CHR_ALL.equals(chrName));
+                    zoomControl.setEnabled(!Globals.CHR_ALL.equals(chrName));
+                }
+            });
+        }
     }
 
 
@@ -264,10 +266,7 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
     private void refreshButtonActionPerformed(java.awt.event.ActionEvent evt) {
 
         IGVEventBus.getInstance().post(new org.broad.igv.event.RefreshEvent());
-        if (IGV.hasInstance()) {
-            IGV.getInstance().doRefresh();
-        }
-        System.gc();
+        (new ReloadTracksMenuAction("",-1, IGV.getInstance())).actionPerformed(evt);
 
     }
 
@@ -311,7 +310,7 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         } else if (e instanceof GenomeResetEvent) {
             refreshGenomeListComboBox();
         } else {
-            log.info("Unknown event class: " + e.getClass());
+            log.warn("Unknown event class: " + e.getClass());
         }
     }
 
@@ -328,7 +327,7 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
     public void searchByLocus(final String searchText) {
 
         if ((searchText != null) && (searchText.length() > 0)) {
-            String homeChr = IGV.getInstance().getGenomeManager().getCurrentGenome().getHomeChromosome();
+            String homeChr = GenomeManager.getInstance().getCurrentGenome().getHomeChromosome();
             if (searchText.equalsIgnoreCase("home") || searchText.equalsIgnoreCase(homeChr)) {
                 homeButtonActionPerformed(null);
             } else {
@@ -350,8 +349,8 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
 
         setLayout(layout);
 
-        detailsBehavior = ShowDetailsBehavior.valueOf((PreferencesManager.getPreferences().get(Constants.DETAILS_BEHAVIOR_KEY,
-                ShowDetailsBehavior.HOVER.name()).toUpperCase()));
+        final String detailsPreference = PreferencesManager.getPreferences().get(Constants.DETAILS_BEHAVIOR_KEY);
+        detailsBehavior = ShowDetailsBehavior.valueOf((detailsPreference.toUpperCase()));
 
         // This controls the vertical height of the command bar
 
@@ -366,8 +365,9 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         locationPanel.add(Box.createRigidArea(new Dimension(10, 36)), JideBoxLayout.FIX);
 
         genomeComboBox = new GenomeComboBox();
-        genomeComboBox.setMinimumSize(new Dimension(180, 27));
-        genomeComboBox.setPreferredSize(new Dimension(180, 27));
+        genomeComboBox.setMinimumSize(new Dimension(210, 27));
+        genomeComboBox.setPreferredSize(new Dimension(210, 27));
+        genomeComboBox.setMaximumSize(new Dimension(300, 27));
         genomeComboBox.setToolTipText(UIConstants.CHANGE_GENOME_TOOLTIP);
 
         genomeComboBox.addPopupMenuListener(new PopupMenuListener() {
@@ -447,11 +447,7 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         homeButton.setMinimumSize(new java.awt.Dimension(32, 32));
         homeButton.setPreferredSize(new java.awt.Dimension(32, 32));
         homeButton.setToolTipText("Jump to whole genome view");
-        homeButton.addActionListener(new java.awt.event.ActionListener() {
-            public void actionPerformed(java.awt.event.ActionEvent evt) {
-                homeButtonActionPerformed(evt);
-            }
-        });
+        homeButton.addActionListener(evt -> homeButtonActionPerformed(evt));
         toolPanel.add(homeButton, JideBoxLayout.FIX);
 
 
@@ -465,11 +461,9 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         backButton.setMaximumSize(new java.awt.Dimension(32, 32));
         backButton.setMinimumSize(new java.awt.Dimension(32, 32));
         backButton.setPreferredSize(new java.awt.Dimension(32, 32));
-        backButton.addActionListener(new java.awt.event.ActionListener() {
-            public void actionPerformed(java.awt.event.ActionEvent evt) {
-                IGV.getInstance().getSession().getHistory().back();
-
-            }
+        backButton.addActionListener(evt -> {
+            final History history = IGV.getInstance().getSession().getHistory();
+            history.back();
         });
         backButton.setEnabled(false);
         toolPanel.add(backButton, JideBoxLayout.FIX);
@@ -482,10 +476,9 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         forwardButton.setMaximumSize(new java.awt.Dimension(32, 32));
         forwardButton.setMinimumSize(new java.awt.Dimension(32, 32));
         forwardButton.setPreferredSize(new java.awt.Dimension(32, 32));
-        forwardButton.addActionListener(new java.awt.event.ActionListener() {
-            public void actionPerformed(java.awt.event.ActionEvent evt) {
-                IGV.getInstance().getSession().getHistory().forward();
-            }
+        forwardButton.addActionListener(evt -> {
+            final History history = IGV.getInstance().getSession().getHistory();
+            history.forward();
         });
         forwardButton.setEnabled(false);
         toolPanel.add(forwardButton, JideBoxLayout.FIX);
@@ -499,12 +492,8 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         refreshButton.setMaximumSize(new java.awt.Dimension(32, 32));
         refreshButton.setMinimumSize(new java.awt.Dimension(32, 32));
         refreshButton.setPreferredSize(new java.awt.Dimension(32, 32));
-        refreshButton.setToolTipText("Refresh the screen");
-        refreshButton.addActionListener(new java.awt.event.ActionListener() {
-            public void actionPerformed(java.awt.event.ActionEvent evt) {
-                refreshButtonActionPerformed(evt);
-            }
-        });
+        refreshButton.setToolTipText("Reload tracks and refresh the screen");
+        refreshButton.addActionListener(evt -> refreshButtonActionPerformed(evt));
         toolPanel.add(refreshButton, JideBoxLayout.FIX);
 
 
@@ -567,11 +556,9 @@ public class IGVCommandBar extends javax.swing.JPanel implements IGVEventObserve
         rulerLineButton.setMaximumSize(new java.awt.Dimension(32, 32));
         rulerLineButton.setMinimumSize(new java.awt.Dimension(32, 32));
         rulerLineButton.setPreferredSize(new java.awt.Dimension(32, 32));
-        rulerLineButton.addActionListener(new java.awt.event.ActionListener() {
-            public void actionPerformed(java.awt.event.ActionEvent evt) {
-                IGV.getInstance().setRulerEnabled(rulerLineButton.isSelected());
-                IGV.getInstance().revalidateTrackPanels();
-            }
+        rulerLineButton.addActionListener(evt -> {
+            IGV.getInstance().setRulerEnabled(rulerLineButton.isSelected());
+            IGV.getInstance().repaint();
         });
         toolPanel.add(rulerLineButton, JideBoxLayout.FIX);
 
