@@ -3,8 +3,8 @@ package org.broad.igv.util;
 import com.google.gson.JsonObject;
 import org.broad.igv.Globals;
 import org.broad.igv.aws.IGVS3Object;
-import org.broad.igv.google.OAuthProvider;
-import org.broad.igv.google.OAuthUtils;
+import org.broad.igv.oauth.OAuthProvider;
+import org.broad.igv.oauth.OAuthUtils;
 import org.broad.igv.logging.LogManager;
 import org.broad.igv.logging.Logger;
 import org.broad.igv.ui.IGVMenuBar;
@@ -135,7 +135,7 @@ public class AmazonUtils {
      */
     public static Credentials GetCognitoAWSCredentials() {
 
-        OAuthProvider provider = OAuthUtils.getInstance().getProvider("Amazon");
+        OAuthProvider provider = OAuthUtils.getInstance().getAWSProvider();
 
         JsonObject igv_oauth_conf = GetCognitoConfig();
         JsonObject response = provider.getResponse();
@@ -225,7 +225,8 @@ public class AmazonUtils {
         if (credentials == null) {
             s3Client = S3Client.builder().region(region).build();
         } else {
-            AwsSessionCredentials creds = AwsSessionCredentials.create(credentials.accessKeyId(),
+            AwsSessionCredentials creds = AwsSessionCredentials.create(
+                    credentials.accessKeyId(),
                     credentials.secretAccessKey(),
                     credentials.sessionToken());
 
@@ -245,7 +246,7 @@ public class AmazonUtils {
         if (bucketsFinalList.isEmpty()) {
 
             if (GetCognitoConfig() != null) {
-                OAuthUtils.getInstance().getProvider("Amazon").getAccessToken();
+                OAuthUtils.getInstance().getAWSProvider().getAccessToken();
                 updateS3Client(GetCognitoAWSCredentials());
             } else {
                 updateS3Client(null);
@@ -406,7 +407,7 @@ public class AmazonUtils {
         log.debug("Listing objects for bucketName: " + bucketName);
 
         if (GetCognitoConfig() != null) {
-            OAuthUtils.getInstance().getProvider("Amazon").getAccessToken();
+            OAuthUtils.getInstance().getAWSProvider().getAccessToken();
             updateS3Client(GetCognitoAWSCredentials());
         } else {
             updateS3Client(null);
@@ -476,7 +477,7 @@ public class AmazonUtils {
         S3Presigner s3Presigner;
 
         if (GetCognitoConfig() != null) {
-            OAuthProvider provider = OAuthUtils.getInstance().getProvider("Amazon");
+            OAuthProvider provider = OAuthUtils.getInstance().getAWSProvider();
             provider.getAccessToken();
 
             Credentials credentials = GetCognitoAWSCredentials();
@@ -541,8 +542,8 @@ public class AmazonUtils {
      */
     public static void checkLogin() {
         if (GetCognitoConfig() != null &&
-                !OAuthUtils.getInstance().getProvider("Amazon").isLoggedIn()) {
-            OAuthUtils.getInstance().getProvider("Amazon").doSecureLogin();
+                !OAuthUtils.getInstance().getAWSProvider().isLoggedIn()) {
+            OAuthUtils.getInstance().getAWSProvider().checkLogin();
         }
     }
 
