@@ -32,7 +32,6 @@ import org.broad.igv.Globals;
 import org.broad.igv.feature.NamedFeature;
 import org.broad.igv.feature.genome.Genome;
 import org.broad.igv.ui.commandbar.GenomeListManager;
-import org.broad.igv.feature.genome.GenomeManager;
 import org.broad.igv.prefs.PreferencesManager;
 import org.broad.igv.tools.IgvTools;
 import org.broad.igv.track.Track;
@@ -45,13 +44,10 @@ import org.junit.Ignore;
 import java.awt.*;
 import java.io.*;
 import java.lang.management.ManagementFactory;
-import java.lang.management.RuntimeMXBean;
 import java.lang.management.ThreadInfo;
 import java.lang.management.ThreadMXBean;
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
-import java.nio.file.Files;
-import java.nio.file.Path;
 import java.util.*;
 
 import static junit.framework.Assert.assertTrue;
@@ -119,7 +115,7 @@ public class TestUtils {
      * @throws InterruptedException
      */
     public static void loadSession(IGV igv, String sessionPath) throws InterruptedException {
-        igv.doRestoreSession(sessionPath, null, false);
+        igv.loadSession(sessionPath, null);
     }
 
     /**
@@ -505,33 +501,8 @@ public class TestUtils {
         return outputFile;
     }
 
-    /**
-     * Note: THIS METHOD IS VERY FRAGILE, NOT GUARANTEED TO WORK ON ALL JVMs
-     * @return
-     */
-    static long getProcessID(){
-        RuntimeMXBean bean = ManagementFactory.getRuntimeMXBean();
-
-        // The name representing the running Java virtual machine.
-        // It returns something like 12345@blah. The value
-        // before the @ symbol is the PID.
-        String jvmName = bean.getName();
-        return Long.valueOf(jvmName.split("@")[0]);
-    }
-
-    /**
-     * Uses lsof, only works on *nix systems
-     *
-     * @return
-     */
-    public static int getNumberOpenFileHandles() throws IOException{
-        long pid = getProcessID();
-        String result = RuntimeUtils.executeShellCommand(new String[]{"lsof", "-p", "" + pid}, null, null, false);
-        return result.split("\n").length;
-    }
-
     public static void resetTestUserDefinedGenomes() throws IOException{
-        File userDefinedGenomeListFile = new File(DirectoryManager.getGenomeCacheDirectory(), GenomeManager.TEST_USER_DEFINED_GENOME_LIST_FILE);
+        File userDefinedGenomeListFile = new File(DirectoryManager.getGenomeCacheDirectory(), GenomeListManager.TEST_USER_DEFINED_GENOME_LIST_FILE);
         userDefinedGenomeListFile.delete();
         userDefinedGenomeListFile.deleteOnExit();
 
